DataTableService

Struct DataTableService 

pub struct DataTableService { /* private fields */ }
Implements a client for the Chronicle API.

Example

use google_cloud_gax::paginator::ItemPaginator as _;
async fn sample(
   project_id: &str,
   location_id: &str,
   instance_id: &str,
) -> anyhow::Result<()> {
    let client = DataTableService::builder().build().await?;
    let mut list = client.list_data_tables()
        .set_parent(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}"))
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}

Service Description

DataTableManager provides an interface for managing data tables.

Configuration

To configure DataTableService use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

  • with_endpoint(): by default this client uses the global default endpoint (https://chronicle.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default.
  • with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.

Pooling and Cloning

DataTableService holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap DataTableService in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl DataTableService

pub fn builder() -> ClientBuilder

Returns a builder for DataTableService.

let client = DataTableService::builder().build().await?;
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Self
where T: DataTableService + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn create_data_table(&self) -> CreateDataTable

Create a new data table.

Example
use google_cloud_chronicle_v1::model::DataTable;
use google_cloud_chronicle_v1::Result;
async fn sample(
   client: &DataTableService, project_id: &str, location_id: &str, instance_id: &str
) -> Result<()> {
    let response = client.create_data_table()
        .set_parent(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}"))
        .set_data_table(
            DataTable::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_data_tables(&self) -> ListDataTables

List data tables.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_chronicle_v1::Result;
async fn sample(
   client: &DataTableService, project_id: &str, location_id: &str, instance_id: &str
) -> Result<()> {
    let mut list = client.list_data_tables()
        .set_parent(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}"))
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_data_table(&self) -> GetDataTable

Get data table info.

Example
use google_cloud_chronicle_v1::Result;
async fn sample(
   client: &DataTableService, project_id: &str, location_id: &str, instance_id: &str, data_table_id: &str
) -> Result<()> {
    let response = client.get_data_table()
        .set_name(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}/dataTables/{data_table_id}"))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_data_table(&self) -> UpdateDataTable

Update data table.

Example
use google_cloud_wkt::FieldMask;
use google_cloud_chronicle_v1::model::DataTable;
use google_cloud_chronicle_v1::Result;
async fn sample(
   client: &DataTableService, project_id: &str, location_id: &str, instance_id: &str, data_table_id: &str
) -> Result<()> {
    let response = client.update_data_table()
        .set_data_table(
            DataTable::new().set_name(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}/dataTables/{data_table_id}"))/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_data_table(&self) -> DeleteDataTable

Delete data table.

Example
use google_cloud_chronicle_v1::Result;
async fn sample(
   client: &DataTableService, project_id: &str, location_id: &str, instance_id: &str, data_table_id: &str
) -> Result<()> {
    client.delete_data_table()
        .set_name(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}/dataTables/{data_table_id}"))
        .send().await?;
    Ok(())
}
pub fn create_data_table_row(&self) -> CreateDataTableRow

Create a new data table row.

Example
use google_cloud_chronicle_v1::model::DataTableRow;
use google_cloud_chronicle_v1::Result;
async fn sample(
   client: &DataTableService, project_id: &str, location_id: &str, instance_id: &str, data_table_id: &str
) -> Result<()> {
    let response = client.create_data_table_row()
        .set_parent(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}/dataTables/{data_table_id}"))
        .set_data_table_row(
            DataTableRow::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_data_table_row(&self) -> UpdateDataTableRow

Update data table row

Example
use google_cloud_wkt::FieldMask;
use google_cloud_chronicle_v1::model::DataTableRow;
use google_cloud_chronicle_v1::Result;
async fn sample(
   client: &DataTableService, project_id: &str, location_id: &str, instance_id: &str, data_table_id: &str, data_table_row_id: &str
) -> Result<()> {
    let response = client.update_data_table_row()
        .set_data_table_row(
            DataTableRow::new().set_name(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}/dataTables/{data_table_id}/dataTableRows/{data_table_row_id}"))/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_data_table_rows(&self) -> ListDataTableRows

List data table rows.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_chronicle_v1::Result;
async fn sample(
   client: &DataTableService, project_id: &str, location_id: &str, instance_id: &str, data_table_id: &str
) -> Result<()> {
    let mut list = client.list_data_table_rows()
        .set_parent(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}/dataTables/{data_table_id}"))
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_data_table_row(&self) -> GetDataTableRow

Get data table row

Example
use google_cloud_chronicle_v1::Result;
async fn sample(
   client: &DataTableService, project_id: &str, location_id: &str, instance_id: &str, data_table_id: &str, data_table_row_id: &str
) -> Result<()> {
    let response = client.get_data_table_row()
        .set_name(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}/dataTables/{data_table_id}/dataTableRows/{data_table_row_id}"))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_data_table_row(&self) -> DeleteDataTableRow

Delete data table row.

Example
use google_cloud_chronicle_v1::Result;
async fn sample(
   client: &DataTableService, project_id: &str, location_id: &str, instance_id: &str, data_table_id: &str, data_table_row_id: &str
) -> Result<()> {
    client.delete_data_table_row()
        .set_name(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}/dataTables/{data_table_id}/dataTableRows/{data_table_row_id}"))
        .send().await?;
    Ok(())
}
pub fn bulk_create_data_table_rows(&self) -> BulkCreateDataTableRows

Create data table rows in bulk.

Example
use google_cloud_chronicle_v1::Result;
async fn sample(
   client: &DataTableService
) -> Result<()> {
    let response = client.bulk_create_data_table_rows()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn bulk_get_data_table_rows(&self) -> BulkGetDataTableRows

Get data table rows in bulk.

Example
use google_cloud_chronicle_v1::Result;
async fn sample(
   client: &DataTableService
) -> Result<()> {
    let response = client.bulk_get_data_table_rows()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn bulk_replace_data_table_rows(&self) -> BulkReplaceDataTableRows

Replace all existing data table rows with new data table rows.

Example
use google_cloud_chronicle_v1::Result;
async fn sample(
   client: &DataTableService
) -> Result<()> {
    let response = client.bulk_replace_data_table_rows()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn bulk_update_data_table_rows(&self) -> BulkUpdateDataTableRows

Update data table rows in bulk.

Example
use google_cloud_chronicle_v1::Result;
async fn sample(
   client: &DataTableService
) -> Result<()> {
    let response = client.bulk_update_data_table_rows()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_data_table_operation_errors(&self) -> GetDataTableOperationErrors

Get the error for a data table operation.

Example
use google_cloud_chronicle_v1::Result;
async fn sample(
   client: &DataTableService, project_id: &str, location_id: &str, instance_id: &str, data_table_operation_errors_id: &str
) -> Result<()> {
    let response = client.get_data_table_operation_errors()
        .set_name(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}/dataTableOperationErrors/{data_table_operation_errors_id}"))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_operations(&self) -> ListOperations

Provides the Operations service functionality in this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_chronicle_v1::Result;
async fn sample(
   client: &DataTableService
) -> Result<()> {
    let mut list = client.list_operations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_operation(&self) -> GetOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_chronicle_v1::Result;
async fn sample(
   client: &DataTableService
) -> Result<()> {
    let response = client.get_operation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_operation(&self) -> DeleteOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_chronicle_v1::Result;
async fn sample(
   client: &DataTableService
) -> Result<()> {
    client.delete_operation()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn cancel_operation(&self) -> CancelOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_chronicle_v1::Result;
async fn sample(
   client: &DataTableService
) -> Result<()> {
    client.cancel_operation()
        /* set fields */
        .send().await?;
    Ok(())
}