pub struct EntityService { /* private fields */ }Expand description
Implements a client for the Chronicle API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
async fn sample(
project_id: &str,
location_id: &str,
instance_id: &str,
) -> anyhow::Result<()> {
let client = EntityService::builder().build().await?;
let mut list = client.list_watchlists()
.set_parent(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Service Description
EntityService contains apis for finding entities.
Configuration
To configure EntityService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://chronicle.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
EntityService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap EntityService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl EntityService
impl EntityService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for EntityService.
let client = EntityService::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: EntityService + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: EntityService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn get_watchlist(&self) -> GetWatchlist
pub fn get_watchlist(&self) -> GetWatchlist
Gets watchlist details for the given watchlist ID.
Example
use google_cloud_chronicle_v1::Result;
async fn sample(
client: &EntityService, project_id: &str, location_id: &str, instance_id: &str, watchlist_id: &str
) -> Result<()> {
let response = client.get_watchlist()
.set_name(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}/watchlists/{watchlist_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_watchlists(&self) -> ListWatchlists
pub fn list_watchlists(&self) -> ListWatchlists
Lists all watchlists for the given instance.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_chronicle_v1::Result;
async fn sample(
client: &EntityService, project_id: &str, location_id: &str, instance_id: &str
) -> Result<()> {
let mut list = client.list_watchlists()
.set_parent(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn create_watchlist(&self) -> CreateWatchlist
pub fn create_watchlist(&self) -> CreateWatchlist
Creates a watchlist for the given instance. Note that there can be at most 200 watchlists per instance.
Example
use google_cloud_chronicle_v1::model::Watchlist;
use google_cloud_chronicle_v1::Result;
async fn sample(
client: &EntityService, project_id: &str, location_id: &str, instance_id: &str
) -> Result<()> {
let response = client.create_watchlist()
.set_parent(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}"))
.set_watchlist_id("watchlist_id_value")
.set_watchlist(
Watchlist::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_watchlist(&self) -> UpdateWatchlist
pub fn update_watchlist(&self) -> UpdateWatchlist
Updates the watchlist for the given instance.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_chronicle_v1::model::Watchlist;
use google_cloud_chronicle_v1::Result;
async fn sample(
client: &EntityService, project_id: &str, location_id: &str, instance_id: &str, watchlist_id: &str
) -> Result<()> {
let response = client.update_watchlist()
.set_watchlist(
Watchlist::new().set_name(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}/watchlists/{watchlist_id}"))/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_watchlist(&self) -> DeleteWatchlist
pub fn delete_watchlist(&self) -> DeleteWatchlist
Deletes the watchlist for the given instance.
Example
use google_cloud_chronicle_v1::Result;
async fn sample(
client: &EntityService, project_id: &str, location_id: &str, instance_id: &str, watchlist_id: &str
) -> Result<()> {
client.delete_watchlist()
.set_name(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}/watchlists/{watchlist_id}"))
.send().await?;
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_chronicle_v1::Result;
async fn sample(
client: &EntityService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_chronicle_v1::Result;
async fn sample(
client: &EntityService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_chronicle_v1::Result;
async fn sample(
client: &EntityService
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_chronicle_v1::Result;
async fn sample(
client: &EntityService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for EntityService
impl Clone for EntityService
Sourcefn clone(&self) -> EntityService
fn clone(&self) -> EntityService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more