pub struct ReferenceListService { /* private fields */ }Expand description
Implements a client for the Chronicle API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
async fn sample(
project_id: &str,
location_id: &str,
instance_id: &str,
) -> anyhow::Result<()> {
let client = ReferenceListService::builder().build().await?;
let mut list = client.list_reference_lists()
.set_parent(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Service Description
ReferenceListService provides an interface for managing reference lists.
Configuration
To configure ReferenceListService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://chronicle.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
ReferenceListService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap ReferenceListService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl ReferenceListService
impl ReferenceListService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for ReferenceListService.
let client = ReferenceListService::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: ReferenceListService + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: ReferenceListService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn get_reference_list(&self) -> GetReferenceList
pub fn get_reference_list(&self) -> GetReferenceList
Gets a single reference list.
Example
use google_cloud_chronicle_v1::Result;
async fn sample(
client: &ReferenceListService, project_id: &str, location_id: &str, instance_id: &str, reference_list_id: &str
) -> Result<()> {
let response = client.get_reference_list()
.set_name(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}/referenceLists/{reference_list_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_reference_lists(&self) -> ListReferenceLists
pub fn list_reference_lists(&self) -> ListReferenceLists
Lists a collection of reference lists.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_chronicle_v1::Result;
async fn sample(
client: &ReferenceListService, project_id: &str, location_id: &str, instance_id: &str
) -> Result<()> {
let mut list = client.list_reference_lists()
.set_parent(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn create_reference_list(&self) -> CreateReferenceList
pub fn create_reference_list(&self) -> CreateReferenceList
Creates a new reference list.
Example
use google_cloud_chronicle_v1::model::ReferenceList;
use google_cloud_chronicle_v1::Result;
async fn sample(
client: &ReferenceListService, project_id: &str, location_id: &str, instance_id: &str
) -> Result<()> {
let response = client.create_reference_list()
.set_parent(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}"))
.set_reference_list(
ReferenceList::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_reference_list(&self) -> UpdateReferenceList
pub fn update_reference_list(&self) -> UpdateReferenceList
Updates an existing reference list.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_chronicle_v1::model::ReferenceList;
use google_cloud_chronicle_v1::Result;
async fn sample(
client: &ReferenceListService, project_id: &str, location_id: &str, instance_id: &str, reference_list_id: &str
) -> Result<()> {
let response = client.update_reference_list()
.set_reference_list(
ReferenceList::new().set_name(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}/referenceLists/{reference_list_id}"))/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_chronicle_v1::Result;
async fn sample(
client: &ReferenceListService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_chronicle_v1::Result;
async fn sample(
client: &ReferenceListService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_chronicle_v1::Result;
async fn sample(
client: &ReferenceListService
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_chronicle_v1::Result;
async fn sample(
client: &ReferenceListService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for ReferenceListService
impl Clone for ReferenceListService
Sourcefn clone(&self) -> ReferenceListService
fn clone(&self) -> ReferenceListService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more