pub struct RuleExecutionErrorService { /* private fields */ }Expand description
Implements a client for the Chronicle API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
async fn sample(
project_id: &str,
location_id: &str,
instance_id: &str,
) -> anyhow::Result<()> {
let client = RuleExecutionErrorService::builder().build().await?;
let mut list = client.list_rule_execution_errors()
.set_parent(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Service Description
RuleExecutionErrorService contains endpoints related to rule execution errors.
Configuration
To configure RuleExecutionErrorService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://chronicle.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured with Private Google Access with VPC Service Controls) may want to override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
RuleExecutionErrorService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap RuleExecutionErrorService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl RuleExecutionErrorService
impl RuleExecutionErrorService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for RuleExecutionErrorService.
let client = RuleExecutionErrorService::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: RuleExecutionErrorService + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: RuleExecutionErrorService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn list_rule_execution_errors(&self) -> ListRuleExecutionErrors
pub fn list_rule_execution_errors(&self) -> ListRuleExecutionErrors
Lists rule execution errors.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_chronicle_v1::Result;
async fn sample(
client: &RuleExecutionErrorService, project_id: &str, location_id: &str, instance_id: &str
) -> Result<()> {
let mut list = client.list_rule_execution_errors()
.set_parent(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_chronicle_v1::Result;
async fn sample(
client: &RuleExecutionErrorService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_chronicle_v1::Result;
async fn sample(
client: &RuleExecutionErrorService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_chronicle_v1::Result;
async fn sample(
client: &RuleExecutionErrorService
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_chronicle_v1::Result;
async fn sample(
client: &RuleExecutionErrorService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for RuleExecutionErrorService
impl Clone for RuleExecutionErrorService
Sourcefn clone(&self) -> RuleExecutionErrorService
fn clone(&self) -> RuleExecutionErrorService
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreAuto Trait Implementations
impl !RefUnwindSafe for RuleExecutionErrorService
impl !UnwindSafe for RuleExecutionErrorService
impl Freeze for RuleExecutionErrorService
impl Send for RuleExecutionErrorService
impl Sync for RuleExecutionErrorService
impl Unpin for RuleExecutionErrorService
impl UnsafeUnpin for RuleExecutionErrorService