#[non_exhaustive]pub struct ChartDatasource {
pub dashboard_query: String,
pub data_sources: Vec<DataSource>,
/* private fields */
}Expand description
Datasource of the chart including the query reference and source name.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.dashboard_query: StringReference to dashboard query resource used in the chart.
data_sources: Vec<DataSource>Name of the datasource used in the chart.
Implementations
Sourceimpl ChartDatasource
impl ChartDatasource
Sourcepub fn set_dashboard_query<T: Into<String>>(self, v: T) -> Self
pub fn set_dashboard_query<T: Into<String>>(self, v: T) -> Self
Sets the value of dashboard_query.
Example
ⓘ
let x = ChartDatasource::new().set_dashboard_query(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}/dashboardQueries/{query_id}"));Sourcepub fn set_data_sources<T, V>(self, v: T) -> Self
pub fn set_data_sources<T, V>(self, v: T) -> Self
Sets the value of data_sources.
Example
ⓘ
use google_cloud_chronicle_v1::model::DataSource;
let x = ChartDatasource::new().set_data_sources([
DataSource::Udm,
DataSource::Entity,
DataSource::IngestionMetrics,
]);Trait Implementations
Sourceimpl Clone for ChartDatasource
impl Clone for ChartDatasource
Sourcefn clone(&self) -> ChartDatasource
fn clone(&self) -> ChartDatasource
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChartDatasource
impl Debug for ChartDatasource
Sourceimpl Default for ChartDatasource
impl Default for ChartDatasource
Sourcefn default() -> ChartDatasource
fn default() -> ChartDatasource
Returns the “default value” for a type. Read more
Sourceimpl Message for ChartDatasource
impl Message for ChartDatasource
Sourceimpl PartialEq for ChartDatasource
impl PartialEq for ChartDatasource
Sourcefn eq(&self, other: &ChartDatasource) -> bool
fn eq(&self, other: &ChartDatasource) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ChartDatasource