Visualization

Struct Visualization 

#[non_exhaustive]
pub struct Visualization {
Show 14 fields pub x_axes: Vec<Axis>, pub y_axes: Vec<Axis>, pub series: Vec<Series>, pub tooltip: Option<Tooltip>, pub legends: Vec<Legend>, pub column_defs: Vec<ColumnDef>, pub table_config: Option<TableConfig>, pub button: Option<Button>, pub markdown: Option<Markdown>, pub series_column: Vec<String>, pub grouping_type: String, pub google_maps_config: Option<GoogleMapsConfig>, pub threshold_coloring_enabled: bool, pub visual_maps: Vec<VisualMap>, /* private fields */
}
Visualization config for a chart. https://echarts.apache.org/en/option.html#series

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
x_axes: Vec<Axis>y_axes: Vec<Axis>series: Vec<Series>tooltip: Option<Tooltip>legends: Vec<Legend>column_defs: Vec<ColumnDef>

Column Definition to represent chart as a table.

table_config: Option<TableConfig>

Optional. Configuration for table appearance.

button: Option<Button>

Button config for a chart if tileType is TILE_TYPE_BUTTON.

markdown: Option<Markdown>

Optional. Markdown config for a chart if tileType is TILE_TYPE_MARKDOWN.

series_column: Vec<String>

Optional. Selected column for series

grouping_type: String

Optional. Selected grouping type for series

google_maps_config: Option<GoogleMapsConfig>

Optional. Google Maps config for a chart if type is GOOGLE MAPS.

threshold_coloring_enabled: bool

Optional. Whether threshold coloring is enabled for the chart. If it’s enabled, the chart will be colored based on the values stored in VisualMap below.

visual_maps: Vec<VisualMap>

Optional. Visual maps for the chart.

Implementations

Source

impl Visualization

pub fn new() -> Self

Creates a new default instance.

pub fn set_x_axes<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Axis>,

Sets the value of x_axes.

Example
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::Axis;
let x = Visualization::new()
    .set_x_axes([
        Axis::default()/* use setters */,
        Axis::default()/* use (different) setters */,
    ]);
pub fn set_y_axes<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Axis>,

Sets the value of y_axes.

Example
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::Axis;
let x = Visualization::new()
    .set_y_axes([
        Axis::default()/* use setters */,
        Axis::default()/* use (different) setters */,
    ]);
pub fn set_series<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Series>,

Sets the value of series.

Example
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::Series;
let x = Visualization::new()
    .set_series([
        Series::default()/* use setters */,
        Series::default()/* use (different) setters */,
    ]);
pub fn set_tooltip<T>(self, v: T) -> Self
where T: Into<Tooltip>,

Sets the value of tooltip.

Example
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::Tooltip;
let x = Visualization::new().set_tooltip(Tooltip::default()/* use setters */);
pub fn set_or_clear_tooltip<T>(self, v: Option<T>) -> Self
where T: Into<Tooltip>,

Sets or clears the value of tooltip.

Example
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::Tooltip;
let x = Visualization::new().set_or_clear_tooltip(Some(Tooltip::default()/* use setters */));
let x = Visualization::new().set_or_clear_tooltip(None::<Tooltip>);
pub fn set_legends<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Legend>,

Sets the value of legends.

Example
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::Legend;
let x = Visualization::new()
    .set_legends([
        Legend::default()/* use setters */,
        Legend::default()/* use (different) setters */,
    ]);
pub fn set_column_defs<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<ColumnDef>,

Sets the value of column_defs.

Example
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::ColumnDef;
let x = Visualization::new()
    .set_column_defs([
        ColumnDef::default()/* use setters */,
        ColumnDef::default()/* use (different) setters */,
    ]);
pub fn set_table_config<T>(self, v: T) -> Self
where T: Into<TableConfig>,

Sets the value of table_config.

Example
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::TableConfig;
let x = Visualization::new().set_table_config(TableConfig::default()/* use setters */);
pub fn set_or_clear_table_config<T>(self, v: Option<T>) -> Self
where T: Into<TableConfig>,

Sets or clears the value of table_config.

Example
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::TableConfig;
let x = Visualization::new().set_or_clear_table_config(Some(TableConfig::default()/* use setters */));
let x = Visualization::new().set_or_clear_table_config(None::<TableConfig>);
pub fn set_button<T>(self, v: T) -> Self
where T: Into<Button>,

Sets the value of button.

Example
use google_cloud_chronicle_v1::model::Button;
let x = Visualization::new().set_button(Button::default()/* use setters */);
pub fn set_or_clear_button<T>(self, v: Option<T>) -> Self
where T: Into<Button>,

Sets or clears the value of button.

Example
use google_cloud_chronicle_v1::model::Button;
let x = Visualization::new().set_or_clear_button(Some(Button::default()/* use setters */));
let x = Visualization::new().set_or_clear_button(None::<Button>);
pub fn set_markdown<T>(self, v: T) -> Self
where T: Into<Markdown>,

Sets the value of markdown.

Example
use google_cloud_chronicle_v1::model::Markdown;
let x = Visualization::new().set_markdown(Markdown::default()/* use setters */);
pub fn set_or_clear_markdown<T>(self, v: Option<T>) -> Self
where T: Into<Markdown>,

Sets or clears the value of markdown.

Example
use google_cloud_chronicle_v1::model::Markdown;
let x = Visualization::new().set_or_clear_markdown(Some(Markdown::default()/* use setters */));
let x = Visualization::new().set_or_clear_markdown(None::<Markdown>);
pub fn set_series_column<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of series_column.

Example
let x = Visualization::new().set_series_column(["a", "b", "c"]);
pub fn set_grouping_type<T: Into<String>>(self, v: T) -> Self

Sets the value of grouping_type.

Example
let x = Visualization::new().set_grouping_type("example");
pub fn set_google_maps_config<T>(self, v: T) -> Self

Sets the value of google_maps_config.

Example
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::GoogleMapsConfig;
let x = Visualization::new().set_google_maps_config(GoogleMapsConfig::default()/* use setters */);
pub fn set_or_clear_google_maps_config<T>(self, v: Option<T>) -> Self

Sets or clears the value of google_maps_config.

Example
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::GoogleMapsConfig;
let x = Visualization::new().set_or_clear_google_maps_config(Some(GoogleMapsConfig::default()/* use setters */));
let x = Visualization::new().set_or_clear_google_maps_config(None::<GoogleMapsConfig>);
pub fn set_threshold_coloring_enabled<T: Into<bool>>(self, v: T) -> Self

Sets the value of threshold_coloring_enabled.

Example
let x = Visualization::new().set_threshold_coloring_enabled(true);
pub fn set_visual_maps<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<VisualMap>,

Sets the value of visual_maps.

Example
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::VisualMap;
let x = Visualization::new()
    .set_visual_maps([
        VisualMap::default()/* use setters */,
        VisualMap::default()/* use (different) setters */,
    ]);