#[non_exhaustive]pub struct GoogleMapsConfig {
pub data_settings: Option<DataSettings>,
pub plot_mode: PlotMode,
pub map_position: Option<MapPosition>,
pub point_settings: Option<PointSettings>,
/* private fields */
}Expand description
Google Maps config for a chart if chart type is map.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data_settings: Option<DataSettings>Optional. Data settings for the map.
plot_mode: PlotModeOptional. Plot mode for the map. This is used to determine whether to show points, heatmap or both.
map_position: Option<MapPosition>Optional. Map position settings for the map.
point_settings: Option<PointSettings>Optional. Point settings for the map.
Implementations
Sourceimpl GoogleMapsConfig
impl GoogleMapsConfig
Sourcepub fn set_data_settings<T>(self, v: T) -> Selfwhere
T: Into<DataSettings>,
pub fn set_data_settings<T>(self, v: T) -> Selfwhere
T: Into<DataSettings>,
Sets the value of data_settings.
Example
ⓘ
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::google_maps_config::DataSettings;
let x = GoogleMapsConfig::new().set_data_settings(DataSettings::default()/* use setters */);Sourcepub fn set_or_clear_data_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataSettings>,
pub fn set_or_clear_data_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataSettings>,
Sets or clears the value of data_settings.
Example
ⓘ
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::google_maps_config::DataSettings;
let x = GoogleMapsConfig::new().set_or_clear_data_settings(Some(DataSettings::default()/* use setters */));
let x = GoogleMapsConfig::new().set_or_clear_data_settings(None::<DataSettings>);Sourcepub fn set_plot_mode<T: Into<PlotMode>>(self, v: T) -> Self
pub fn set_plot_mode<T: Into<PlotMode>>(self, v: T) -> Self
Sourcepub fn set_map_position<T>(self, v: T) -> Selfwhere
T: Into<MapPosition>,
pub fn set_map_position<T>(self, v: T) -> Selfwhere
T: Into<MapPosition>,
Sets the value of map_position.
Example
ⓘ
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::google_maps_config::MapPosition;
let x = GoogleMapsConfig::new().set_map_position(MapPosition::default()/* use setters */);Sourcepub fn set_or_clear_map_position<T>(self, v: Option<T>) -> Selfwhere
T: Into<MapPosition>,
pub fn set_or_clear_map_position<T>(self, v: Option<T>) -> Selfwhere
T: Into<MapPosition>,
Sets or clears the value of map_position.
Example
ⓘ
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::google_maps_config::MapPosition;
let x = GoogleMapsConfig::new().set_or_clear_map_position(Some(MapPosition::default()/* use setters */));
let x = GoogleMapsConfig::new().set_or_clear_map_position(None::<MapPosition>);Sourcepub fn set_point_settings<T>(self, v: T) -> Selfwhere
T: Into<PointSettings>,
pub fn set_point_settings<T>(self, v: T) -> Selfwhere
T: Into<PointSettings>,
Sets the value of point_settings.
Example
ⓘ
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::google_maps_config::PointSettings;
let x = GoogleMapsConfig::new().set_point_settings(PointSettings::default()/* use setters */);Sourcepub fn set_or_clear_point_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<PointSettings>,
pub fn set_or_clear_point_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<PointSettings>,
Sets or clears the value of point_settings.
Example
ⓘ
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::google_maps_config::PointSettings;
let x = GoogleMapsConfig::new().set_or_clear_point_settings(Some(PointSettings::default()/* use setters */));
let x = GoogleMapsConfig::new().set_or_clear_point_settings(None::<PointSettings>);Trait Implementations
Sourceimpl Clone for GoogleMapsConfig
impl Clone for GoogleMapsConfig
Sourcefn clone(&self) -> GoogleMapsConfig
fn clone(&self) -> GoogleMapsConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GoogleMapsConfig
impl Debug for GoogleMapsConfig
Sourceimpl Default for GoogleMapsConfig
impl Default for GoogleMapsConfig
Sourcefn default() -> GoogleMapsConfig
fn default() -> GoogleMapsConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for GoogleMapsConfig
impl Message for GoogleMapsConfig
Sourceimpl PartialEq for GoogleMapsConfig
impl PartialEq for GoogleMapsConfig
Sourcefn eq(&self, other: &GoogleMapsConfig) -> bool
fn eq(&self, other: &GoogleMapsConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for GoogleMapsConfig