#[non_exhaustive]pub struct VisualMap {
pub visual_map_type: VisualMapType,
pub pieces: Vec<VisualMapPiece>,
/* private fields */
}Expand description
Conveys what range of values should be rendered in what color. This field is used when threshold_coloring_enabled is true.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.visual_map_type: VisualMapTypeOptional. Contains one of the valid visual map types such as ‘continuous’ or ‘piecewise’.
pieces: Vec<VisualMapPiece>Optional. Pieces of the visual map.
Implementations
Sourceimpl VisualMap
impl VisualMap
Sourcepub fn set_visual_map_type<T: Into<VisualMapType>>(self, v: T) -> Self
pub fn set_visual_map_type<T: Into<VisualMapType>>(self, v: T) -> Self
Sets the value of visual_map_type.
Example
ⓘ
use google_cloud_chronicle_v1::model::VisualMapType;
let x0 = VisualMap::new().set_visual_map_type(VisualMapType::Continuous);
let x1 = VisualMap::new().set_visual_map_type(VisualMapType::Piecewise);Sourcepub fn set_pieces<T, V>(self, v: T) -> Self
pub fn set_pieces<T, V>(self, v: T) -> Self