#[non_exhaustive]pub struct VisualMapPiece {
pub min: Option<i64>,
pub max: Option<i64>,
pub color: String,
pub label: String,
/* private fields */
}Expand description
An ECharts visual map of type ‘piecewise’ contain many pieces. Each piece has a min, max, and color with which it’s rendered.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.min: Option<i64>Optional. Minimum value for the piece.
max: Option<i64>Optional. Minimum value for the piece.
color: StringOptional. Color to render the piece in when the value is between min and max.
label: StringOptional. Label used in visual map controller.
Implementations