#[non_exhaustive]pub enum Label {
DataAccessLabel(String),
LogType(String),
AssetNamespace(String),
IngestionLabel(Box<IngestionLabel>),
}Expand description
The unique identifier for the label.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DataAccessLabel(String)
The name of the data access label.
LogType(String)
The name of the log type.
AssetNamespace(String)
The asset namespace configured in the forwarder of the customer’s events.
IngestionLabel(Box<IngestionLabel>)
The ingestion label configured in the forwarder of the customer’s events.