#[non_exhaustive]pub enum DataSource {
Show 16 variants
Unspecified,
Udm,
Entity,
IngestionMetrics,
RuleDetections,
Rulesets,
Global,
IocMatches,
Rules,
SoarCases,
SoarPlaybooks,
SoarCaseHistory,
DataTable,
Investigation,
InvestigationFeedback,
UnknownValue(UnknownValue),
}Expand description
LINT.IfChange(data_sources)
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Udm
Entity
IngestionMetrics
RuleDetections
RULE_DETECTIONS is used for detections datasource.
Rulesets
RULESETS is used for ruleset with detections datasource.
Global
GLOBAL is used for standard time range filter.
IocMatches
IOC_MATCHES is used for ioc_matches datasource.
Rules
RULES is used for rules datasource.
SoarCases
SOAR Cases - identified as case.
SoarPlaybooks
SOAR Playbooks - identified as playbook.
SoarCaseHistory
SOAR Case History - identified as case_history.
DataTable
DATA_TABLE is used for data tables source.
Investigation
INVESTIGATION is used as the data source for triage agent investigations.
Identified as gemini_investigation.
InvestigationFeedback
INVESTIGATION_FEEDBACK is used as the data source for user feedback on
triage agent investigations. Identified as gemini_investigation_feedback.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using DataSource::value or DataSource::name.
Implementations