#[non_exhaustive]pub enum DataTableUpdateSource {
Unspecified,
User,
Rule,
Search,
UnknownValue(UnknownValue),
}Expand description
DataTableUpdateSource denotes the source that updated the data table.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
The data table is updated by the user.
User
The data table is updated by the user.
Rule
The data table is updated by the rule.
Search
The data table is updated by the search.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using DataTableUpdateSource::value or DataTableUpdateSource::name.
Implementations