#[non_exhaustive]pub enum LanguageFeature {
Unspecified,
Joins,
Stages,
DataTables,
UnknownValue(UnknownValue),
}Expand description
A language feature describes a specific capability or syntax of the query
language used in a dashboard query, such as JOINS, STAGES, or
DATA_TABLES.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
Language feature is unknown.
Joins
Language feature is joins.
Stages
Language feature is stages.
DataTables
Language feature is data table.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using LanguageFeature::value or LanguageFeature::name.
Implementations