#[non_exhaustive]pub enum PlotMode {
Unspecified,
Points,
Heatmap,
Both,
UnknownValue(UnknownValue),
}Expand description
Plot mode for the map.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
Plot mode is not specified.
Points
Plot mode is points.
Heatmap
Plot mode is heatmap.
Both
Plot mode is both points and heatmap.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using PlotMode::value or PlotMode::name.
Implementations