#[non_exhaustive]pub enum ReferenceListView {
Unspecified,
Basic,
Full,
UnknownValue(UnknownValue),
}Expand description
ReferenceListView is a mechanism for viewing partial responses of the ReferenceList resource.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The default / unset value. The API will default to the BASIC view for ListReferenceLists. The API will default to the FULL view for methods that return a single ReferenceList resource.
Basic
Include metadata about the ReferenceList. This is the default view for ListReferenceLists.
Full
Include all details about the ReferenceList: metadata, content lines, associated rule counts. This is the default view for GetReferenceList.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ReferenceListView::value or ReferenceListView::name.
Implementations