AdvancedFilterConfig

Struct AdvancedFilterConfig 

#[non_exhaustive]
pub struct AdvancedFilterConfig { pub token: String, pub prefix: String, pub suffix: String, pub separator: String, pub multiple_allowed: bool, pub default_values: Vec<String>, pub skip_default_affixes: bool, pub value_source: Option<ValueSource>, /* private fields */ }
Advanced filter configuration for the filter widget.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
token: String

Required. The token name to look for in the query (e.g., “hostname”). The system will automatically wrap this in ‘$’ (e.g., “$hostname$”).

prefix: String

Optional. String to prepend to the final replaced value (e.g., “/”, “^(”, “"”).

suffix: String

Optional. String to append to the final replaced value (e.g., “/”, “)$”, “"”).

separator: String

Optional. Delimiter to join multiple selected values (e.g., “|”, “ OR field = “).

multiple_allowed: bool

Optional. Whether to allow selection of multiple values.

default_values: Vec<String>

Optional. Default values to use if no value is selected/provided.

skip_default_affixes: bool

Optional. Whether to skip the configured prefix and suffix when using default values. If true, default values are inserted raw (joined by the separator).

value_source: Option<ValueSource>

Required. Source of the values for the filter.

Implementations

Source

impl AdvancedFilterConfig

pub fn new() -> Self

Creates a new default instance.

pub fn set_token<T: Into<String>>(self, v: T) -> Self

Sets the value of token.

Example
let x = AdvancedFilterConfig::new().set_token("example");
pub fn set_prefix<T: Into<String>>(self, v: T) -> Self

Sets the value of prefix.

Example
let x = AdvancedFilterConfig::new().set_prefix("example");
pub fn set_suffix<T: Into<String>>(self, v: T) -> Self

Sets the value of suffix.

Example
let x = AdvancedFilterConfig::new().set_suffix("example");
pub fn set_separator<T: Into<String>>(self, v: T) -> Self

Sets the value of separator.

Example
let x = AdvancedFilterConfig::new().set_separator("example");
pub fn set_multiple_allowed<T: Into<bool>>(self, v: T) -> Self

Sets the value of multiple_allowed.

Example
let x = AdvancedFilterConfig::new().set_multiple_allowed(true);
pub fn set_default_values<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of default_values.

Example
let x = AdvancedFilterConfig::new().set_default_values(["a", "b", "c"]);
pub fn set_skip_default_affixes<T: Into<bool>>(self, v: T) -> Self

Sets the value of skip_default_affixes.

Example
let x = AdvancedFilterConfig::new().set_skip_default_affixes(true);
pub fn set_value_source<T>(self, v: T) -> Self
where T: Into<ValueSource>,

Sets the value of value_source.

Example
use google_cloud_chronicle_v1::model::advanced_filter_config::ValueSource;
let x = AdvancedFilterConfig::new().set_value_source(ValueSource::default()/* use setters */);
pub fn set_or_clear_value_source<T>(self, v: Option<T>) -> Self
where T: Into<ValueSource>,

Sets or clears the value of value_source.

Example
use google_cloud_chronicle_v1::model::advanced_filter_config::ValueSource;
let x = AdvancedFilterConfig::new().set_or_clear_value_source(Some(ValueSource::default()/* use setters */));
let x = AdvancedFilterConfig::new().set_or_clear_value_source(None::<ValueSource>);