BigQueryExport

Struct BigQueryExport 

#[non_exhaustive]
pub struct BigQueryExport { pub name: String, pub provisioned: bool, pub big_query_export_package: BigQueryExportPackage, pub entity_graph_settings: Option<DataSourceExportSettings>, pub ioc_matches_settings: Option<DataSourceExportSettings>, pub rule_detections_settings: Option<DataSourceExportSettings>, pub udm_events_aggregates_settings: Option<DataSourceExportSettings>, pub udm_events_settings: Option<DataSourceExportSettings>, /* private fields */ }
This resource represents the BigQuery export configuration for a Chronicle instance which includes Google Cloud Platform resources like Cloud Storage buckets, BigQuery datasets etc and the export settings for each data source.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Identifier. The resource name of the BigQueryExport. Format: projects/{project}/locations/{location}/instances/{instance}/bigQueryExport

provisioned: bool

Output only. Whether the BigQueryExport has been provisioned for the Chronicle instance.

big_query_export_package: BigQueryExportPackage

Output only. The BigQueryExportPackage entitled for the Chronicle instance.

entity_graph_settings: Option<DataSourceExportSettings>

Optional. The export settings for the Entity Graph data source.

ioc_matches_settings: Option<DataSourceExportSettings>

Optional. The export settings for the IOC Matches data source.

rule_detections_settings: Option<DataSourceExportSettings>

Optional. The export settings for the Rule Detections data source.

udm_events_aggregates_settings: Option<DataSourceExportSettings>

Optional. The export settings for the UDM Events Aggregates data source.

udm_events_settings: Option<DataSourceExportSettings>

Optional. The export settings for the UDM Events data source.

Implementations

Source

impl BigQueryExport

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = BigQueryExport::new().set_name(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}/bigQueryExport"));
pub fn set_provisioned<T: Into<bool>>(self, v: T) -> Self

Sets the value of provisioned.

Example
let x = BigQueryExport::new().set_provisioned(true);
pub fn set_big_query_export_package<T: Into<BigQueryExportPackage>>( self, v: T, ) -> Self

Sets the value of big_query_export_package.

Example
use google_cloud_chronicle_v1::model::BigQueryExportPackage;
let x0 = BigQueryExport::new().set_big_query_export_package(BigQueryExportPackage::Byobq);
let x1 = BigQueryExport::new().set_big_query_export_package(BigQueryExportPackage::Advanced);
pub fn set_entity_graph_settings<T>(self, v: T) -> Self

Sets the value of entity_graph_settings.

Example
use google_cloud_chronicle_v1::model::DataSourceExportSettings;
let x = BigQueryExport::new().set_entity_graph_settings(DataSourceExportSettings::default()/* use setters */);
pub fn set_or_clear_entity_graph_settings<T>(self, v: Option<T>) -> Self

Sets or clears the value of entity_graph_settings.

Example
use google_cloud_chronicle_v1::model::DataSourceExportSettings;
let x = BigQueryExport::new().set_or_clear_entity_graph_settings(Some(DataSourceExportSettings::default()/* use setters */));
let x = BigQueryExport::new().set_or_clear_entity_graph_settings(None::<DataSourceExportSettings>);
pub fn set_ioc_matches_settings<T>(self, v: T) -> Self

Sets the value of ioc_matches_settings.

Example
use google_cloud_chronicle_v1::model::DataSourceExportSettings;
let x = BigQueryExport::new().set_ioc_matches_settings(DataSourceExportSettings::default()/* use setters */);
pub fn set_or_clear_ioc_matches_settings<T>(self, v: Option<T>) -> Self

Sets or clears the value of ioc_matches_settings.

Example
use google_cloud_chronicle_v1::model::DataSourceExportSettings;
let x = BigQueryExport::new().set_or_clear_ioc_matches_settings(Some(DataSourceExportSettings::default()/* use setters */));
let x = BigQueryExport::new().set_or_clear_ioc_matches_settings(None::<DataSourceExportSettings>);
pub fn set_rule_detections_settings<T>(self, v: T) -> Self

Sets the value of rule_detections_settings.

Example
use google_cloud_chronicle_v1::model::DataSourceExportSettings;
let x = BigQueryExport::new().set_rule_detections_settings(DataSourceExportSettings::default()/* use setters */);
pub fn set_or_clear_rule_detections_settings<T>(self, v: Option<T>) -> Self

Sets or clears the value of rule_detections_settings.

Example
use google_cloud_chronicle_v1::model::DataSourceExportSettings;
let x = BigQueryExport::new().set_or_clear_rule_detections_settings(Some(DataSourceExportSettings::default()/* use setters */));
let x = BigQueryExport::new().set_or_clear_rule_detections_settings(None::<DataSourceExportSettings>);
pub fn set_udm_events_aggregates_settings<T>(self, v: T) -> Self

Sets the value of udm_events_aggregates_settings.

Example
use google_cloud_chronicle_v1::model::DataSourceExportSettings;
let x = BigQueryExport::new().set_udm_events_aggregates_settings(DataSourceExportSettings::default()/* use setters */);
pub fn set_or_clear_udm_events_aggregates_settings<T>( self, v: Option<T>, ) -> Self

Sets or clears the value of udm_events_aggregates_settings.

Example
use google_cloud_chronicle_v1::model::DataSourceExportSettings;
let x = BigQueryExport::new().set_or_clear_udm_events_aggregates_settings(Some(DataSourceExportSettings::default()/* use setters */));
let x = BigQueryExport::new().set_or_clear_udm_events_aggregates_settings(None::<DataSourceExportSettings>);
pub fn set_udm_events_settings<T>(self, v: T) -> Self

Sets the value of udm_events_settings.

Example
use google_cloud_chronicle_v1::model::DataSourceExportSettings;
let x = BigQueryExport::new().set_udm_events_settings(DataSourceExportSettings::default()/* use setters */);
pub fn set_or_clear_udm_events_settings<T>(self, v: Option<T>) -> Self

Sets or clears the value of udm_events_settings.

Example
use google_cloud_chronicle_v1::model::DataSourceExportSettings;
let x = BigQueryExport::new().set_or_clear_udm_events_settings(Some(DataSourceExportSettings::default()/* use setters */));
let x = BigQueryExport::new().set_or_clear_udm_events_settings(None::<DataSourceExportSettings>);