ColumnMetadata

Struct ColumnMetadata 

#[non_exhaustive]
pub struct ColumnMetadata { pub column: String, pub field_path: String, pub function_name: String, pub function_module: String, pub data_source: DataSource, pub timestamp_metadata: Option<TimestampMetadata>, pub longitude: bool, pub latitude: bool, pub selected: bool, pub unselected: bool, /* private fields */ }
Metadata of the column.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
column: String

Name of the column.

field_path: String

Field path of the queried field, if any.

function_name: String

Name of the function used to query the field, if any.

function_module: String

Module of the function used to query the field, if any.

data_source: DataSource

Data source queried.

timestamp_metadata: Option<TimestampMetadata>

Timestamp Metadata

longitude: bool

Whether the column is a longitude field.

latitude: bool

Whether the column is a latitude field.

selected: bool

Whether the column is selected in the final response.

unselected: bool

Whether the column is unselected in the final response.

Implementations

Source

impl ColumnMetadata

pub fn new() -> Self

Creates a new default instance.

pub fn set_column<T: Into<String>>(self, v: T) -> Self

Sets the value of column.

Example
let x = ColumnMetadata::new().set_column("example");
pub fn set_field_path<T: Into<String>>(self, v: T) -> Self

Sets the value of field_path.

Example
let x = ColumnMetadata::new().set_field_path("example");
pub fn set_function_name<T: Into<String>>(self, v: T) -> Self

Sets the value of function_name.

Example
let x = ColumnMetadata::new().set_function_name("example");
pub fn set_function_module<T: Into<String>>(self, v: T) -> Self

Sets the value of function_module.

Example
let x = ColumnMetadata::new().set_function_module("example");
pub fn set_data_source<T: Into<DataSource>>(self, v: T) -> Self

Sets the value of data_source.

Example
use google_cloud_chronicle_v1::model::DataSource;
let x0 = ColumnMetadata::new().set_data_source(DataSource::Udm);
let x1 = ColumnMetadata::new().set_data_source(DataSource::Entity);
let x2 = ColumnMetadata::new().set_data_source(DataSource::IngestionMetrics);
pub fn set_timestamp_metadata<T>(self, v: T) -> Self

Sets the value of timestamp_metadata.

Example
use google_cloud_chronicle_v1::model::TimestampMetadata;
let x = ColumnMetadata::new().set_timestamp_metadata(TimestampMetadata::default()/* use setters */);
pub fn set_or_clear_timestamp_metadata<T>(self, v: Option<T>) -> Self

Sets or clears the value of timestamp_metadata.

Example
use google_cloud_chronicle_v1::model::TimestampMetadata;
let x = ColumnMetadata::new().set_or_clear_timestamp_metadata(Some(TimestampMetadata::default()/* use setters */));
let x = ColumnMetadata::new().set_or_clear_timestamp_metadata(None::<TimestampMetadata>);
pub fn set_longitude<T: Into<bool>>(self, v: T) -> Self

Sets the value of longitude.

Example
let x = ColumnMetadata::new().set_longitude(true);
pub fn set_latitude<T: Into<bool>>(self, v: T) -> Self

Sets the value of latitude.

Example
let x = ColumnMetadata::new().set_latitude(true);
pub fn set_selected<T: Into<bool>>(self, v: T) -> Self

Sets the value of selected.

Example
let x = ColumnMetadata::new().set_selected(true);
pub fn set_unselected<T: Into<bool>>(self, v: T) -> Self

Sets the value of unselected.

Example
let x = ColumnMetadata::new().set_unselected(true);