CreateDataAccessLabelRequest

Struct CreateDataAccessLabelRequest 

#[non_exhaustive]
pub struct CreateDataAccessLabelRequest { pub parent: String, pub data_access_label: Option<DataAccessLabel>, pub data_access_label_id: String, /* private fields */ }
Request message for CreateDataAccessLabel.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. The parent resource where this Data Access Label will be created. Format: projects/{project}/locations/{location}/instances/{instance}

data_access_label: Option<DataAccessLabel>

Required. Data access label to create.

data_access_label_id: String

Required. The ID to use for the data access label, which will become the label’s display name and the final component of the label’s resource name. The maximum number of characters should be 63. Regex pattern is as per AIP: https://google.aip.dev/122#resource-id-segments

Implementations

Source

impl CreateDataAccessLabelRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = CreateDataAccessLabelRequest::new().set_parent(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}"));
pub fn set_data_access_label<T>(self, v: T) -> Self

Sets the value of data_access_label.

Example
use google_cloud_chronicle_v1::model::DataAccessLabel;
let x = CreateDataAccessLabelRequest::new().set_data_access_label(DataAccessLabel::default()/* use setters */);
pub fn set_or_clear_data_access_label<T>(self, v: Option<T>) -> Self

Sets or clears the value of data_access_label.

Example
use google_cloud_chronicle_v1::model::DataAccessLabel;
let x = CreateDataAccessLabelRequest::new().set_or_clear_data_access_label(Some(DataAccessLabel::default()/* use setters */));
let x = CreateDataAccessLabelRequest::new().set_or_clear_data_access_label(None::<DataAccessLabel>);
pub fn set_data_access_label_id<T: Into<String>>(self, v: T) -> Self

Sets the value of data_access_label_id.

Example
let x = CreateDataAccessLabelRequest::new().set_data_access_label_id("example");