#[non_exhaustive]pub struct CreateNativeDashboardRequest {
pub parent: String,
pub native_dashboard: Option<NativeDashboard>,
/* private fields */
}Expand description
Request message to create a dashboard.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource where this dashboard will be created. Format: projects/{project}/locations/{location}/instances/{instance}
native_dashboard: Option<NativeDashboard>Required. The dashboard to create.
Implementations
Sourceimpl CreateNativeDashboardRequest
impl CreateNativeDashboardRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_native_dashboard<T>(self, v: T) -> Selfwhere
T: Into<NativeDashboard>,
pub fn set_native_dashboard<T>(self, v: T) -> Selfwhere
T: Into<NativeDashboard>,
Sets the value of native_dashboard.
Example
ⓘ
use google_cloud_chronicle_v1::model::NativeDashboard;
let x = CreateNativeDashboardRequest::new().set_native_dashboard(NativeDashboard::default()/* use setters */);Sourcepub fn set_or_clear_native_dashboard<T>(self, v: Option<T>) -> Selfwhere
T: Into<NativeDashboard>,
pub fn set_or_clear_native_dashboard<T>(self, v: Option<T>) -> Selfwhere
T: Into<NativeDashboard>,
Sets or clears the value of native_dashboard.
Example
ⓘ
use google_cloud_chronicle_v1::model::NativeDashboard;
let x = CreateNativeDashboardRequest::new().set_or_clear_native_dashboard(Some(NativeDashboard::default()/* use setters */));
let x = CreateNativeDashboardRequest::new().set_or_clear_native_dashboard(None::<NativeDashboard>);Trait Implementations
Sourceimpl Clone for CreateNativeDashboardRequest
impl Clone for CreateNativeDashboardRequest
Sourcefn clone(&self) -> CreateNativeDashboardRequest
fn clone(&self) -> CreateNativeDashboardRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateNativeDashboardRequest
impl Debug for CreateNativeDashboardRequest
Sourceimpl Default for CreateNativeDashboardRequest
impl Default for CreateNativeDashboardRequest
Sourcefn default() -> CreateNativeDashboardRequest
fn default() -> CreateNativeDashboardRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for CreateNativeDashboardRequest
impl PartialEq for CreateNativeDashboardRequest
Sourcefn eq(&self, other: &CreateNativeDashboardRequest) -> bool
fn eq(&self, other: &CreateNativeDashboardRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateNativeDashboardRequest