#[non_exhaustive]pub struct CreateWatchlistRequest {
pub parent: String,
pub watchlist_id: String,
pub watchlist: Option<Watchlist>,
/* private fields */
}Expand description
Request message for creating watchlist.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource where this watchlist will be created.
Format: projects/{project}/locations/{location}/instances/{instance}
watchlist_id: StringOptional. The ID to use for the watchlist, which will become the final component of the watchlist’s resource name.
This value should be 4-63 characters, and valid characters are /[a-z][0-9]-/.
watchlist: Option<Watchlist>Required. The watchlist to create.
Implementations
Sourceimpl CreateWatchlistRequest
impl CreateWatchlistRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_watchlist_id<T: Into<String>>(self, v: T) -> Self
pub fn set_watchlist_id<T: Into<String>>(self, v: T) -> Self
Sets the value of watchlist_id.
Example
ⓘ
let x = CreateWatchlistRequest::new().set_watchlist_id("example");Sourcepub fn set_watchlist<T>(self, v: T) -> Self
pub fn set_watchlist<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_watchlist<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_watchlist<T>(self, v: Option<T>) -> Self