#[non_exhaustive]pub struct DashboardQuery {
pub name: String,
pub query: String,
pub input: Option<Input>,
pub dashboard_chart: String,
pub etag: String,
/* private fields */
}Expand description
DashboardQuery resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. Name of the dashboardQuery.
query: StringRequired. Search query string.
input: Option<Input>Required. Inputs to the query.
dashboard_chart: StringOutput only. DashboardChart this query belongs to.
etag: StringOptional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
Implementations
Sourceimpl DashboardQuery
impl DashboardQuery
Sourcepub fn set_or_clear_input<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_input<T>(self, v: Option<T>) -> Self
Sourcepub fn set_dashboard_chart<T: Into<String>>(self, v: T) -> Self
pub fn set_dashboard_chart<T: Into<String>>(self, v: T) -> Self
Sets the value of dashboard_chart.
Example
ⓘ
let x = DashboardQuery::new().set_dashboard_chart(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}/dashboardCharts/{chart_id}"));Trait Implementations
Sourceimpl Clone for DashboardQuery
impl Clone for DashboardQuery
Sourcefn clone(&self) -> DashboardQuery
fn clone(&self) -> DashboardQuery
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DashboardQuery
impl Debug for DashboardQuery
Sourceimpl Default for DashboardQuery
impl Default for DashboardQuery
Sourcefn default() -> DashboardQuery
fn default() -> DashboardQuery
Returns the “default value” for a type. Read more
Sourceimpl Message for DashboardQuery
impl Message for DashboardQuery
Sourceimpl PartialEq for DashboardQuery
impl PartialEq for DashboardQuery
Sourcefn eq(&self, other: &DashboardQuery) -> bool
fn eq(&self, other: &DashboardQuery) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DashboardQuery