#[non_exhaustive]pub struct DataAccessLabel {
pub name: String,
pub display_name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub author: String,
pub last_editor: String,
pub description: String,
pub definition: Option<Definition>,
/* private fields */
}Expand description
A DataAccessLabel is a label on events to define user access to data.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe unique resource name of the data access label.
display_name: StringOutput only. The short name displayed for the label as it appears on event data.
create_time: Option<Timestamp>Output only. The time at which the data access label was created.
update_time: Option<Timestamp>Output only. The time at which the data access label was last updated.
Output only. The user who created the data access label.
last_editor: StringOutput only. The user who last updated the data access label.
description: StringOptional. A description of the data access label for a human reader.
definition: Option<Definition>Required. The definition of the data access label that determines which data gets tagged with this label.
Implementations
Sourceimpl DataAccessLabel
impl DataAccessLabel
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
let x = DataAccessLabel::new().set_display_name("example");Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = DataAccessLabel::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = DataAccessLabel::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = DataAccessLabel::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = DataAccessLabel::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = DataAccessLabel::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = DataAccessLabel::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_last_editor<T: Into<String>>(self, v: T) -> Self
pub fn set_last_editor<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_definition<T: Into<Option<Definition>>>(self, v: T) -> Self
pub fn set_definition<T: Into<Option<Definition>>>(self, v: T) -> Self
Sets the value of definition.
Note that all the setters affecting definition are mutually
exclusive.
Example
use google_cloud_chronicle_v1::model::data_access_label::Definition;
let x = DataAccessLabel::new().set_definition(Some(Definition::UdmQuery("example".to_string())));Sourcepub fn udm_query(&self) -> Option<&String>
pub fn udm_query(&self) -> Option<&String>
The value of definition
if it holds a UdmQuery, None if the field is not set or
holds a different branch.
Sourcepub fn set_udm_query<T: Into<String>>(self, v: T) -> Self
pub fn set_udm_query<T: Into<String>>(self, v: T) -> Self
Sets the value of definition
to hold a UdmQuery.
Note that all the setters affecting definition are
mutually exclusive.
Example
let x = DataAccessLabel::new().set_udm_query("example");
assert!(x.udm_query().is_some());Trait Implementations
Sourceimpl Clone for DataAccessLabel
impl Clone for DataAccessLabel
Sourcefn clone(&self) -> DataAccessLabel
fn clone(&self) -> DataAccessLabel
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DataAccessLabel
impl Debug for DataAccessLabel
Sourceimpl Default for DataAccessLabel
impl Default for DataAccessLabel
Sourcefn default() -> DataAccessLabel
fn default() -> DataAccessLabel
Sourceimpl Message for DataAccessLabel
impl Message for DataAccessLabel
Sourceimpl PartialEq for DataAccessLabel
impl PartialEq for DataAccessLabel
Sourcefn eq(&self, other: &DataAccessLabel) -> bool
fn eq(&self, other: &DataAccessLabel) -> bool
self and other values to be equal, and is used by ==.