DataAccessLabelReference

Struct DataAccessLabelReference 

#[non_exhaustive]
pub struct DataAccessLabelReference { pub display_name: String, pub label: Option<Label>, /* private fields */ }
Reference object to a data access label.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
display_name: String

Output only. The display name of the label. Data access label and log types’s name will match the display name of the resource. The asset namespace will match the namespace itself. The ingestion key value pair will match the key of the tuple.

label: Option<Label>

The unique identifier for the label.

Implementations

Source

impl DataAccessLabelReference

pub fn new() -> Self

Creates a new default instance.

pub fn set_display_name<T: Into<String>>(self, v: T) -> Self

Sets the value of display_name.

Example
let x = DataAccessLabelReference::new().set_display_name("example");
pub fn set_label<T: Into<Option<Label>>>(self, v: T) -> Self

Sets the value of label.

Note that all the setters affecting label are mutually exclusive.

Example
use google_cloud_chronicle_v1::model::data_access_label_reference::Label;
let x = DataAccessLabelReference::new().set_label(Some(Label::DataAccessLabel("example".to_string())));
pub fn data_access_label(&self) -> Option<&String>

The value of label if it holds a DataAccessLabel, None if the field is not set or holds a different branch.

pub fn set_data_access_label<T: Into<String>>(self, v: T) -> Self

Sets the value of label to hold a DataAccessLabel.

Note that all the setters affecting label are mutually exclusive.

Example
let x = DataAccessLabelReference::new().set_data_access_label("example");
assert!(x.data_access_label().is_some());
assert!(x.log_type().is_none());
assert!(x.asset_namespace().is_none());
assert!(x.ingestion_label().is_none());
pub fn log_type(&self) -> Option<&String>

The value of label if it holds a LogType, None if the field is not set or holds a different branch.

pub fn set_log_type<T: Into<String>>(self, v: T) -> Self

Sets the value of label to hold a LogType.

Note that all the setters affecting label are mutually exclusive.

Example
let x = DataAccessLabelReference::new().set_log_type("example");
assert!(x.log_type().is_some());
assert!(x.data_access_label().is_none());
assert!(x.asset_namespace().is_none());
assert!(x.ingestion_label().is_none());
pub fn asset_namespace(&self) -> Option<&String>

The value of label if it holds a AssetNamespace, None if the field is not set or holds a different branch.

pub fn set_asset_namespace<T: Into<String>>(self, v: T) -> Self

Sets the value of label to hold a AssetNamespace.

Note that all the setters affecting label are mutually exclusive.

Example
let x = DataAccessLabelReference::new().set_asset_namespace("example");
assert!(x.asset_namespace().is_some());
assert!(x.data_access_label().is_none());
assert!(x.log_type().is_none());
assert!(x.ingestion_label().is_none());
pub fn ingestion_label(&self) -> Option<&Box<IngestionLabel>>

The value of label if it holds a IngestionLabel, None if the field is not set or holds a different branch.

pub fn set_ingestion_label<T: Into<Box<IngestionLabel>>>(self, v: T) -> Self

Sets the value of label to hold a IngestionLabel.

Note that all the setters affecting label are mutually exclusive.

Example
use google_cloud_chronicle_v1::model::IngestionLabel;
let x = DataAccessLabelReference::new().set_ingestion_label(IngestionLabel::default()/* use setters */);
assert!(x.ingestion_label().is_some());
assert!(x.data_access_label().is_none());
assert!(x.log_type().is_none());
assert!(x.asset_namespace().is_none());