#[non_exhaustive]pub struct DataSourceExportSettings {
pub enabled: bool,
pub retention_days: i32,
pub latest_export_job_state: LatestExportJobState,
pub data_freshness_time: Option<Timestamp>,
pub data_volume: i64,
/* private fields */
}Expand description
The export settings for a data source.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enabled: boolRequired. Whether the data source is enabled for export.
retention_days: i32Required. The retention period for the data source in days.
latest_export_job_state: LatestExportJobStateOutput only. The state of the latest data source export job.
data_freshness_time: Option<Timestamp>Output only. The data freshness of the given export which represents the time bucket at which the latest event was exported.
data_volume: i64Output only. The stored data volume of all the exports.
Implementations
Sourceimpl DataSourceExportSettings
impl DataSourceExportSettings
Sourcepub fn set_enabled<T: Into<bool>>(self, v: T) -> Self
pub fn set_enabled<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_retention_days<T: Into<i32>>(self, v: T) -> Self
pub fn set_retention_days<T: Into<i32>>(self, v: T) -> Self
Sets the value of retention_days.
Example
ⓘ
let x = DataSourceExportSettings::new().set_retention_days(42);Sourcepub fn set_latest_export_job_state<T: Into<LatestExportJobState>>(
self,
v: T,
) -> Self
pub fn set_latest_export_job_state<T: Into<LatestExportJobState>>( self, v: T, ) -> Self
Sets the value of latest_export_job_state.
Example
ⓘ
use google_cloud_chronicle_v1::model::LatestExportJobState;
let x0 = DataSourceExportSettings::new().set_latest_export_job_state(LatestExportJobState::Success);
let x1 = DataSourceExportSettings::new().set_latest_export_job_state(LatestExportJobState::Failed);Sourcepub fn set_data_freshness_time<T>(self, v: T) -> Self
pub fn set_data_freshness_time<T>(self, v: T) -> Self
Sets the value of data_freshness_time.
Example
ⓘ
use wkt::Timestamp;
let x = DataSourceExportSettings::new().set_data_freshness_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_data_freshness_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_data_freshness_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of data_freshness_time.
Example
ⓘ
use wkt::Timestamp;
let x = DataSourceExportSettings::new().set_or_clear_data_freshness_time(Some(Timestamp::default()/* use setters */));
let x = DataSourceExportSettings::new().set_or_clear_data_freshness_time(None::<Timestamp>);Sourcepub fn set_data_volume<T: Into<i64>>(self, v: T) -> Self
pub fn set_data_volume<T: Into<i64>>(self, v: T) -> Self
Sets the value of data_volume.
Example
ⓘ
let x = DataSourceExportSettings::new().set_data_volume(42);Trait Implementations
Sourceimpl Clone for DataSourceExportSettings
impl Clone for DataSourceExportSettings
Sourcefn clone(&self) -> DataSourceExportSettings
fn clone(&self) -> DataSourceExportSettings
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DataSourceExportSettings
impl Debug for DataSourceExportSettings
Sourceimpl Default for DataSourceExportSettings
impl Default for DataSourceExportSettings
Sourcefn default() -> DataSourceExportSettings
fn default() -> DataSourceExportSettings
Returns the “default value” for a type. Read more
Sourceimpl Message for DataSourceExportSettings
impl Message for DataSourceExportSettings
Sourceimpl PartialEq for DataSourceExportSettings
impl PartialEq for DataSourceExportSettings
Sourcefn eq(&self, other: &DataSourceExportSettings) -> bool
fn eq(&self, other: &DataSourceExportSettings) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DataSourceExportSettings