#[non_exhaustive]pub struct DataTable {Show 14 fields
pub name: String,
pub display_name: String,
pub description: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub column_info: Vec<DataTableColumnInfo>,
pub data_table_uuid: String,
pub rules: Vec<String>,
pub rule_associations_count: i32,
pub row_time_to_live: String,
pub approximate_row_count: i64,
pub scope_info: Option<DataTableScopeInfo>,
pub update_source: DataTableUpdateSource,
pub row_time_to_live_update_time: Option<Timestamp>,
/* private fields */
}Expand description
DataTable represents the data table resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The resource name of the data table Format: “{project}/locations/{location}/instances/{instance}/dataTables/{data_table}”
display_name: StringOutput only. The unique display name of the data table.
description: StringRequired. A user-provided description of the data table.
create_time: Option<Timestamp>Output only. Table create time
update_time: Option<Timestamp>Output only. Table update time
column_info: Vec<DataTableColumnInfo>Immutable. Details of all the columns in the table
data_table_uuid: StringOutput only. Data table unique id
rules: Vec<String>Output only. The resource names for the associated Rules that use this data table. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}. {rule} here refers to the rule id.
rule_associations_count: i32Output only. The count of rules using the data table.
row_time_to_live: StringOptional. User-provided TTL of the data table.
approximate_row_count: i64Output only. The count of rows in the data table.
scope_info: Option<DataTableScopeInfo>Optional. The scope info of the data table. During data table creation, if this field is not set, the data table without scopes (an unscoped table) will be created for a global user. For a scoped user, this field must be set. During data table update, if scope_info is requested to be updated, this field must be set.
update_source: DataTableUpdateSourceOutput only. Source of the data table update.
row_time_to_live_update_time: Option<Timestamp>Output only. Last update time of the TTL of the data table.
Implementations
Sourceimpl DataTable
impl DataTable
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = DataTable::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = DataTable::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = DataTable::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = DataTable::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = DataTable::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = DataTable::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_column_info<T, V>(self, v: T) -> Self
pub fn set_column_info<T, V>(self, v: T) -> Self
Sets the value of column_info.
Example
use google_cloud_chronicle_v1::model::DataTableColumnInfo;
let x = DataTable::new()
.set_column_info([
DataTableColumnInfo::default()/* use setters */,
DataTableColumnInfo::default()/* use (different) setters */,
]);Sourcepub fn set_data_table_uuid<T: Into<String>>(self, v: T) -> Self
pub fn set_data_table_uuid<T: Into<String>>(self, v: T) -> Self
Sets the value of data_table_uuid.
Example
let x = DataTable::new().set_data_table_uuid("example");Sourcepub fn set_rule_associations_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_rule_associations_count<T: Into<i32>>(self, v: T) -> Self
Sets the value of rule_associations_count.
Example
let x = DataTable::new().set_rule_associations_count(42);Sourcepub fn set_row_time_to_live<T: Into<String>>(self, v: T) -> Self
pub fn set_row_time_to_live<T: Into<String>>(self, v: T) -> Self
Sets the value of row_time_to_live.
Example
let x = DataTable::new().set_row_time_to_live("example");Sourcepub fn set_approximate_row_count<T: Into<i64>>(self, v: T) -> Self
pub fn set_approximate_row_count<T: Into<i64>>(self, v: T) -> Self
Sets the value of approximate_row_count.
Example
let x = DataTable::new().set_approximate_row_count(42);Sourcepub fn set_scope_info<T>(self, v: T) -> Selfwhere
T: Into<DataTableScopeInfo>,
pub fn set_scope_info<T>(self, v: T) -> Selfwhere
T: Into<DataTableScopeInfo>,
Sets the value of scope_info.
Example
use google_cloud_chronicle_v1::model::DataTableScopeInfo;
let x = DataTable::new().set_scope_info(DataTableScopeInfo::default()/* use setters */);Sourcepub fn set_or_clear_scope_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataTableScopeInfo>,
pub fn set_or_clear_scope_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataTableScopeInfo>,
Sets or clears the value of scope_info.
Example
use google_cloud_chronicle_v1::model::DataTableScopeInfo;
let x = DataTable::new().set_or_clear_scope_info(Some(DataTableScopeInfo::default()/* use setters */));
let x = DataTable::new().set_or_clear_scope_info(None::<DataTableScopeInfo>);Sourcepub fn set_update_source<T: Into<DataTableUpdateSource>>(self, v: T) -> Self
pub fn set_update_source<T: Into<DataTableUpdateSource>>(self, v: T) -> Self
Sets the value of update_source.
Example
use google_cloud_chronicle_v1::model::DataTableUpdateSource;
let x0 = DataTable::new().set_update_source(DataTableUpdateSource::User);
let x1 = DataTable::new().set_update_source(DataTableUpdateSource::Rule);
let x2 = DataTable::new().set_update_source(DataTableUpdateSource::Search);Sourcepub fn set_row_time_to_live_update_time<T>(self, v: T) -> Self
pub fn set_row_time_to_live_update_time<T>(self, v: T) -> Self
Sets the value of row_time_to_live_update_time.
Example
use wkt::Timestamp;
let x = DataTable::new().set_row_time_to_live_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_row_time_to_live_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_row_time_to_live_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of row_time_to_live_update_time.
Example
use wkt::Timestamp;
let x = DataTable::new().set_or_clear_row_time_to_live_update_time(Some(Timestamp::default()/* use setters */));
let x = DataTable::new().set_or_clear_row_time_to_live_update_time(None::<Timestamp>);