#[non_exhaustive]pub struct DataTableRow {
pub name: String,
pub values: Vec<String>,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub row_time_to_live: String,
/* private fields */
}Expand description
DataTableRow represents a single row in a data table.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringIdentifier. The resource name of the data table Format: projects/{project}/locations/{location}/instances/{instance}/dataTables/{data_table}/dataTableRows/{data_table_row}
values: Vec<String>Required. All column values for a single row. The values should be in the same order as the columns of the data tables.
create_time: Option<Timestamp>Output only. DataTableRow create time
update_time: Option<Timestamp>Output only. DataTableRow update time
row_time_to_live: StringOptional. User-provided TTL of the data table row.
Implementations
Sourceimpl DataTableRow
impl DataTableRow
Sourcepub fn set_values<T, V>(self, v: T) -> Self
pub fn set_values<T, V>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
ⓘ
use wkt::Timestamp;
let x = DataTableRow::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
ⓘ
use wkt::Timestamp;
let x = DataTableRow::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = DataTableRow::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
ⓘ
use wkt::Timestamp;
let x = DataTableRow::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
ⓘ
use wkt::Timestamp;
let x = DataTableRow::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = DataTableRow::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_row_time_to_live<T: Into<String>>(self, v: T) -> Self
pub fn set_row_time_to_live<T: Into<String>>(self, v: T) -> Self
Sets the value of row_time_to_live.
Example
ⓘ
let x = DataTableRow::new().set_row_time_to_live("example");Trait Implementations
Sourceimpl Clone for DataTableRow
impl Clone for DataTableRow
Sourcefn clone(&self) -> DataTableRow
fn clone(&self) -> DataTableRow
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DataTableRow
impl Debug for DataTableRow
Sourceimpl Default for DataTableRow
impl Default for DataTableRow
Sourcefn default() -> DataTableRow
fn default() -> DataTableRow
Returns the “default value” for a type. Read more
Sourceimpl Message for DataTableRow
impl Message for DataTableRow
Sourceimpl PartialEq for DataTableRow
impl PartialEq for DataTableRow
impl StructuralPartialEq for DataTableRow