DataTableScopeInfo

Struct DataTableScopeInfo 

#[non_exhaustive]
pub struct DataTableScopeInfo { pub data_access_scopes: Vec<String>, /* private fields */ }
DataTableScopeInfo specifies the scope info of the data table.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
data_access_scopes: Vec<String>

Required. Contains the list of scope names of the data table. If the list is empty, the data table is treated as unscoped. The scope names should be full resource names and should be of the format: “projects/{project}/locations/{location}/instances/{instance}/dataAccessScopes/{scope_name}”

Implementations

Source

impl DataTableScopeInfo

pub fn new() -> Self

Creates a new default instance.

pub fn set_data_access_scopes<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of data_access_scopes.

Example
let x = DataTableScopeInfo::new().set_data_access_scopes(["a", "b", "c"]);