#[non_exhaustive]pub struct DeleteDataTableRequest {
pub name: String,
pub force: bool,
/* private fields */
}Expand description
Request message for deleting data tables.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name of the data table to delete. Format projects/{project}/locations/{location}/instances/{instances}/dataTables/{data_table}
force: boolOptional. If set to true, any rows under this data table will also be deleted. (Otherwise, the request will only work if the data table has no rows.)
Implementations