DeleteRuleRequest

Struct DeleteRuleRequest 

#[non_exhaustive]
pub struct DeleteRuleRequest { pub name: String, pub force: bool, /* private fields */ }
Request message for the DeleteRule method.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Required. The name of the rule to delete. A rule revision timestamp cannot be specified as part of the name, as deleting specific revisions is not supported. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}

force: bool

Optional. If set to true, any retrohunts and any detections associated with the rule will also be deleted. If set to false, the call will only succeed if the rule has no associated retrohunts, including completed retrohunts, and no associated detections. Regardless of this field’s value, the rule deployment associated with this rule will also be deleted.

Implementations

Source

impl DeleteRuleRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = DeleteRuleRequest::new().set_name(format!("projects/{project_id}/locations/{location_id}/instances/{instance_id}/rules/{rule_id}"));
pub fn set_force<T: Into<bool>>(self, v: T) -> Self

Sets the value of force.

Example
let x = DeleteRuleRequest::new().set_force(true);