#[non_exhaustive]pub struct ExecuteDashboardQueryRequest {
pub parent: String,
pub query: Option<DashboardQuery>,
pub filters: Vec<DashboardFilter>,
pub clear_cache: bool,
pub use_previous_time_range: bool,
/* private fields */
}Expand description
Request message to execute a dashboard query.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent, under which to run this dashboardQuery. Format: projects/{project}/locations/{location}/instances/{instance}
query: Option<DashboardQuery>Required. The query to execute and get results back for. QueryID or ‘query’, ‘input.time_window’ fields will be used. Use ‘native_dashboard’ and ‘dashboard_chart’ fields if it is an in-dashboard query.
filters: Vec<DashboardFilter>Optional. Dashboard level filters other than query string.
clear_cache: boolOptional. When true, the backend would read from the database, rather than fetching data directly from the cache.
use_previous_time_range: boolOptional. When true, the backend will execute the query against the previous time range of the query.
Implementations
Sourceimpl ExecuteDashboardQueryRequest
impl ExecuteDashboardQueryRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_query<T>(self, v: T) -> Selfwhere
T: Into<DashboardQuery>,
pub fn set_query<T>(self, v: T) -> Selfwhere
T: Into<DashboardQuery>,
Sourcepub fn set_or_clear_query<T>(self, v: Option<T>) -> Selfwhere
T: Into<DashboardQuery>,
pub fn set_or_clear_query<T>(self, v: Option<T>) -> Selfwhere
T: Into<DashboardQuery>,
Sets or clears the value of query.
Example
use google_cloud_chronicle_v1::model::DashboardQuery;
let x = ExecuteDashboardQueryRequest::new().set_or_clear_query(Some(DashboardQuery::default()/* use setters */));
let x = ExecuteDashboardQueryRequest::new().set_or_clear_query(None::<DashboardQuery>);Sourcepub fn set_filters<T, V>(self, v: T) -> Self
pub fn set_filters<T, V>(self, v: T) -> Self
Sourcepub fn set_clear_cache<T: Into<bool>>(self, v: T) -> Self
pub fn set_clear_cache<T: Into<bool>>(self, v: T) -> Self
Sets the value of clear_cache.
Example
let x = ExecuteDashboardQueryRequest::new().set_clear_cache(true);Sourcepub fn set_use_previous_time_range<T: Into<bool>>(self, v: T) -> Self
pub fn set_use_previous_time_range<T: Into<bool>>(self, v: T) -> Self
Sets the value of use_previous_time_range.
Example
let x = ExecuteDashboardQueryRequest::new().set_use_previous_time_range(true);Trait Implementations
Sourceimpl Clone for ExecuteDashboardQueryRequest
impl Clone for ExecuteDashboardQueryRequest
Sourcefn clone(&self) -> ExecuteDashboardQueryRequest
fn clone(&self) -> ExecuteDashboardQueryRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ExecuteDashboardQueryRequest
impl Debug for ExecuteDashboardQueryRequest
Sourceimpl Default for ExecuteDashboardQueryRequest
impl Default for ExecuteDashboardQueryRequest
Sourcefn default() -> ExecuteDashboardQueryRequest
fn default() -> ExecuteDashboardQueryRequest
Sourceimpl PartialEq for ExecuteDashboardQueryRequest
impl PartialEq for ExecuteDashboardQueryRequest
Sourcefn eq(&self, other: &ExecuteDashboardQueryRequest) -> bool
fn eq(&self, other: &ExecuteDashboardQueryRequest) -> bool
self and other values to be equal, and is used by ==.