#[non_exhaustive]pub struct FeaturedContentMetadata {
pub id: String,
pub display_name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub author: String,
pub certified: bool,
pub description: String,
pub categories: Vec<String>,
pub version: String,
pub verified: Option<bool>,
pub source_type: ContentSourceType,
/* private fields */
}Expand description
FeaturedContentMetadata holds metadata about the Featured Content.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringRequired. Unique identifier of the featured content.
display_name: StringOutput only. The display name of the featured content.
create_time: Option<Timestamp>Output only. Timestamp indicating when the item was created.
update_time: Option<Timestamp>Output only. Timestamp indicating when the item was updated.
Output only. Content item author full name.
certified: boolOutput only. Determine if this content item is officially certified by Google or created by the community.
description: StringOutput only. The description of the content item.
categories: Vec<String>Output only. Categories the content is associated with.
version: StringOutput only. Featured content version (Major.Minor.Patch).
verified: Option<bool>Output only. Whether the content is verified by Google (applicable for 3rd party content).
source_type: ContentSourceTypeOutput only. The source type of the content.
Implementations
Sourceimpl FeaturedContentMetadata
impl FeaturedContentMetadata
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
let x = FeaturedContentMetadata::new().set_display_name("example");Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = FeaturedContentMetadata::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = FeaturedContentMetadata::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = FeaturedContentMetadata::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = FeaturedContentMetadata::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = FeaturedContentMetadata::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = FeaturedContentMetadata::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_certified<T: Into<bool>>(self, v: T) -> Self
pub fn set_certified<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_description<T: Into<String>>(self, v: T) -> Self
pub fn set_description<T: Into<String>>(self, v: T) -> Self
Sets the value of description.
Example
let x = FeaturedContentMetadata::new().set_description("example");Sourcepub fn set_categories<T, V>(self, v: T) -> Self
pub fn set_categories<T, V>(self, v: T) -> Self
Sets the value of categories.
Example
let x = FeaturedContentMetadata::new().set_categories(["a", "b", "c"]);Sourcepub fn set_version<T: Into<String>>(self, v: T) -> Self
pub fn set_version<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_verified<T>(self, v: T) -> Self
pub fn set_verified<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_verified<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_verified<T>(self, v: Option<T>) -> Self
Sourcepub fn set_source_type<T: Into<ContentSourceType>>(self, v: T) -> Self
pub fn set_source_type<T: Into<ContentSourceType>>(self, v: T) -> Self
Sets the value of source_type.
Example
use google_cloud_chronicle_v1::model::featured_content_metadata::ContentSourceType;
let x0 = FeaturedContentMetadata::new().set_source_type(ContentSourceType::Google);
let x1 = FeaturedContentMetadata::new().set_source_type(ContentSourceType::Community);
let x2 = FeaturedContentMetadata::new().set_source_type(ContentSourceType::Partner);Trait Implementations
Sourceimpl Clone for FeaturedContentMetadata
impl Clone for FeaturedContentMetadata
Sourcefn clone(&self) -> FeaturedContentMetadata
fn clone(&self) -> FeaturedContentMetadata
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for FeaturedContentMetadata
impl Debug for FeaturedContentMetadata
Sourceimpl Default for FeaturedContentMetadata
impl Default for FeaturedContentMetadata
Sourcefn default() -> FeaturedContentMetadata
fn default() -> FeaturedContentMetadata
Sourceimpl Message for FeaturedContentMetadata
impl Message for FeaturedContentMetadata
Sourceimpl PartialEq for FeaturedContentMetadata
impl PartialEq for FeaturedContentMetadata
Sourcefn eq(&self, other: &FeaturedContentMetadata) -> bool
fn eq(&self, other: &FeaturedContentMetadata) -> bool
self and other values to be equal, and is used by ==.