#[non_exhaustive]pub struct GetDataTableRequest {
pub name: String,
/* private fields */
}Expand description
A request to get details about a data table.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name of the data table to retrieve. Format: projects/{project}/locations/{location}/instances/{instances}/dataTables/{data_table}
Implementations