#[non_exhaustive]pub struct GetReferenceListRequest {
pub name: String,
pub view: ReferenceListView,
/* private fields */
}Expand description
A request to get details about a reference list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name of the reference list to retrieve.
Format:
projects/{project}/locations/{locations}/instances/{instance}/referenceLists/{reference_list}
view: ReferenceListViewHow much of the ReferenceList to view. Defaults to REFERENCE_LIST_VIEW_FULL.
Implementations