#[non_exhaustive]pub struct ListDataAccessLabelsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
/* private fields */
}Expand description
Request message for ListDataAccessLabels.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource where this data access label will be created.
Format: projects/{project}/locations/{location}/instances/{instance}
page_size: i32The maximum number of data access labels to return. The service may return fewer than this value. If unspecified, at most 100 data access labels will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
page_token: StringA page token, received from a previous ListDataAccessLabelsRequest call.
Provide this to retrieve the subsequent page.
filter: StringOptional. A filter which should follow the guidelines of AIP-160. Supports filtering on all fieds of DataAccessLabel and all operations as mentioned in https://google.aip.dev/160. example filter: “create_time greater than "2023-04-21T11:30:00-04:00" OR display_name:"-21-1"”.
Implementations
Sourceimpl ListDataAccessLabelsRequest
impl ListDataAccessLabelsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListDataAccessLabelsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListDataAccessLabelsRequest
impl Clone for ListDataAccessLabelsRequest
Sourcefn clone(&self) -> ListDataAccessLabelsRequest
fn clone(&self) -> ListDataAccessLabelsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ListDataAccessLabelsRequest
impl Debug for ListDataAccessLabelsRequest
Sourceimpl Default for ListDataAccessLabelsRequest
impl Default for ListDataAccessLabelsRequest
Sourcefn default() -> ListDataAccessLabelsRequest
fn default() -> ListDataAccessLabelsRequest
Sourceimpl PartialEq for ListDataAccessLabelsRequest
impl PartialEq for ListDataAccessLabelsRequest
Sourcefn eq(&self, other: &ListDataAccessLabelsRequest) -> bool
fn eq(&self, other: &ListDataAccessLabelsRequest) -> bool
self and other values to be equal, and is used by ==.