#[non_exhaustive]pub struct ListDataAccessLabelsResponse {
pub data_access_labels: Vec<DataAccessLabel>,
pub next_page_token: String,
/* private fields */
}Expand description
Response message for ListDataAccessLabels.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data_access_labels: Vec<DataAccessLabel>List of data access labels.
next_page_token: StringA token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
Implementations
Sourceimpl ListDataAccessLabelsResponse
impl ListDataAccessLabelsResponse
Sourcepub fn set_data_access_labels<T, V>(self, v: T) -> Self
pub fn set_data_access_labels<T, V>(self, v: T) -> Self
Sets the value of data_access_labels.
Example
ⓘ
use google_cloud_chronicle_v1::model::DataAccessLabel;
let x = ListDataAccessLabelsResponse::new()
.set_data_access_labels([
DataAccessLabel::default()/* use setters */,
DataAccessLabel::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListDataAccessLabelsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListDataAccessLabelsResponse
impl Clone for ListDataAccessLabelsResponse
Sourcefn clone(&self) -> ListDataAccessLabelsResponse
fn clone(&self) -> ListDataAccessLabelsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListDataAccessLabelsResponse
impl Debug for ListDataAccessLabelsResponse
Sourceimpl Default for ListDataAccessLabelsResponse
impl Default for ListDataAccessLabelsResponse
Sourcefn default() -> ListDataAccessLabelsResponse
fn default() -> ListDataAccessLabelsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListDataAccessLabelsResponse
impl PartialEq for ListDataAccessLabelsResponse
Sourcefn eq(&self, other: &ListDataAccessLabelsResponse) -> bool
fn eq(&self, other: &ListDataAccessLabelsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListDataAccessLabelsResponse