#[non_exhaustive]pub struct ListDataAccessScopesRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
/* private fields */
}Expand description
Request message for ListDataAccessScopes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource where this data access scope will be created.
Format: projects/{project}/locations/{location}/instances/{instance}
page_size: i32The maximum number of data access scopes to return. The service may return fewer than this value. If unspecified, at most 100 data access scopes will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
page_token: StringA page token, received from a previous ListDataAccessScopesRequest call.
Provide this to retrieve the subsequent page.
filter: StringOptional. A filter which should follow the guidelines of AIP-160. Supports filtering on all fieds of DataAccessScope and all operations as mentioned in https://google.aip.dev/160. example filter: “create_time greater than "2023-04-21T11:30:00-04:00" OR display_name:"-21-1"”.
Implementations
Sourceimpl ListDataAccessScopesRequest
impl ListDataAccessScopesRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListDataAccessScopesRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListDataAccessScopesRequest
impl Clone for ListDataAccessScopesRequest
Sourcefn clone(&self) -> ListDataAccessScopesRequest
fn clone(&self) -> ListDataAccessScopesRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ListDataAccessScopesRequest
impl Debug for ListDataAccessScopesRequest
Sourceimpl Default for ListDataAccessScopesRequest
impl Default for ListDataAccessScopesRequest
Sourcefn default() -> ListDataAccessScopesRequest
fn default() -> ListDataAccessScopesRequest
Sourceimpl PartialEq for ListDataAccessScopesRequest
impl PartialEq for ListDataAccessScopesRequest
Sourcefn eq(&self, other: &ListDataAccessScopesRequest) -> bool
fn eq(&self, other: &ListDataAccessScopesRequest) -> bool
self and other values to be equal, and is used by ==.