#[non_exhaustive]pub struct ListDataAccessScopesResponse {
pub data_access_scopes: Vec<DataAccessScope>,
pub global_data_access_scope_granted: Option<bool>,
pub next_page_token: String,
/* private fields */
}Expand description
Response message for ListDataAccessScopes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data_access_scopes: Vec<DataAccessScope>List of data access scopes.
global_data_access_scope_granted: Option<bool>Whether or not global scope is granted to the user.
next_page_token: StringA token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
Implementations
Sourceimpl ListDataAccessScopesResponse
impl ListDataAccessScopesResponse
Sourcepub fn set_data_access_scopes<T, V>(self, v: T) -> Self
pub fn set_data_access_scopes<T, V>(self, v: T) -> Self
Sets the value of data_access_scopes.
Example
ⓘ
use google_cloud_chronicle_v1::model::DataAccessScope;
let x = ListDataAccessScopesResponse::new()
.set_data_access_scopes([
DataAccessScope::default()/* use setters */,
DataAccessScope::default()/* use (different) setters */,
]);Sourcepub fn set_global_data_access_scope_granted<T>(self, v: T) -> Self
pub fn set_global_data_access_scope_granted<T>(self, v: T) -> Self
Sets the value of global_data_access_scope_granted.
Example
ⓘ
let x = ListDataAccessScopesResponse::new().set_global_data_access_scope_granted(true);Sourcepub fn set_or_clear_global_data_access_scope_granted<T>(
self,
v: Option<T>,
) -> Self
pub fn set_or_clear_global_data_access_scope_granted<T>( self, v: Option<T>, ) -> Self
Sets or clears the value of global_data_access_scope_granted.
Example
ⓘ
let x = ListDataAccessScopesResponse::new().set_or_clear_global_data_access_scope_granted(Some(false));
let x = ListDataAccessScopesResponse::new().set_or_clear_global_data_access_scope_granted(None::<bool>);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListDataAccessScopesResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListDataAccessScopesResponse
impl Clone for ListDataAccessScopesResponse
Sourcefn clone(&self) -> ListDataAccessScopesResponse
fn clone(&self) -> ListDataAccessScopesResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListDataAccessScopesResponse
impl Debug for ListDataAccessScopesResponse
Sourceimpl Default for ListDataAccessScopesResponse
impl Default for ListDataAccessScopesResponse
Sourcefn default() -> ListDataAccessScopesResponse
fn default() -> ListDataAccessScopesResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListDataAccessScopesResponse
impl PartialEq for ListDataAccessScopesResponse
Sourcefn eq(&self, other: &ListDataAccessScopesResponse) -> bool
fn eq(&self, other: &ListDataAccessScopesResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListDataAccessScopesResponse