#[non_exhaustive]pub struct ListDataTablesRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub order_by: String,
/* private fields */
}Expand description
A request for a list of data tables.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource where this data table will be created. Format: projects/{project}/locations/{location}/instances/{instance}
page_size: i32Optional. The maximum number of data tables to return. The service may return fewer than this value. If unspecified, at most 100 data tables will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
page_token: StringOptional. A page token, received from a previous ListDataTables call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to
ListDataTables must match the call that provided the page
token.
order_by: StringOptional. Configures ordering of DataTables in the response. Note: Our implementation currently supports order by “create_time asc” only
Implementations
Sourceimpl ListDataTablesRequest
impl ListDataTablesRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListDataTablesRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListDataTablesRequest
impl Clone for ListDataTablesRequest
Sourcefn clone(&self) -> ListDataTablesRequest
fn clone(&self) -> ListDataTablesRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ListDataTablesRequest
impl Debug for ListDataTablesRequest
Sourceimpl Default for ListDataTablesRequest
impl Default for ListDataTablesRequest
Sourcefn default() -> ListDataTablesRequest
fn default() -> ListDataTablesRequest
Sourceimpl Message for ListDataTablesRequest
impl Message for ListDataTablesRequest
Sourceimpl PartialEq for ListDataTablesRequest
impl PartialEq for ListDataTablesRequest
Sourcefn eq(&self, other: &ListDataTablesRequest) -> bool
fn eq(&self, other: &ListDataTablesRequest) -> bool
self and other values to be equal, and is used by ==.