#[non_exhaustive]pub struct ListReferenceListsResponse {
pub reference_lists: Vec<ReferenceList>,
pub next_page_token: String,
/* private fields */
}Expand description
A response to a request for a list of reference lists.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.reference_lists: Vec<ReferenceList>The reference lists. Ordered in ascending alphabetical order by name.
next_page_token: StringA token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
Implementations
Sourceimpl ListReferenceListsResponse
impl ListReferenceListsResponse
Sourcepub fn set_reference_lists<T, V>(self, v: T) -> Self
pub fn set_reference_lists<T, V>(self, v: T) -> Self
Sets the value of reference_lists.
Example
ⓘ
use google_cloud_chronicle_v1::model::ReferenceList;
let x = ListReferenceListsResponse::new()
.set_reference_lists([
ReferenceList::default()/* use setters */,
ReferenceList::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListReferenceListsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListReferenceListsResponse
impl Clone for ListReferenceListsResponse
Sourcefn clone(&self) -> ListReferenceListsResponse
fn clone(&self) -> ListReferenceListsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListReferenceListsResponse
impl Debug for ListReferenceListsResponse
Sourceimpl Default for ListReferenceListsResponse
impl Default for ListReferenceListsResponse
Sourcefn default() -> ListReferenceListsResponse
fn default() -> ListReferenceListsResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for ListReferenceListsResponse
impl Message for ListReferenceListsResponse
Sourceimpl PartialEq for ListReferenceListsResponse
impl PartialEq for ListReferenceListsResponse
Sourcefn eq(&self, other: &ListReferenceListsResponse) -> bool
fn eq(&self, other: &ListReferenceListsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListReferenceListsResponse