#[non_exhaustive]pub struct ListRuleDeploymentsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
/* private fields */
}Expand description
Request message for ListRuleDeployments.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The collection of all parents which own all rule deployments. The
“-” wildcard token must be used as the rule identifier in the resource
path. Format:
projects/{project}/locations/{location}/instances/{instance}/rules/-
page_size: i32The maximum number of rule deployments to return. The service may return fewer than this value. If unspecified, at most 100 rule deployments will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
page_token: StringA page token, received from a previous ListRuleDeployments call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to ListRuleDeployments
must match the call that provided the page token.
filter: StringA filter that can be used to retrieve specific rule deployments. The following fields are filterable: archived, name
Implementations
Sourceimpl ListRuleDeploymentsRequest
impl ListRuleDeploymentsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListRuleDeploymentsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListRuleDeploymentsRequest
impl Clone for ListRuleDeploymentsRequest
Sourcefn clone(&self) -> ListRuleDeploymentsRequest
fn clone(&self) -> ListRuleDeploymentsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ListRuleDeploymentsRequest
impl Debug for ListRuleDeploymentsRequest
Sourceimpl Default for ListRuleDeploymentsRequest
impl Default for ListRuleDeploymentsRequest
Sourcefn default() -> ListRuleDeploymentsRequest
fn default() -> ListRuleDeploymentsRequest
Sourceimpl Message for ListRuleDeploymentsRequest
impl Message for ListRuleDeploymentsRequest
Sourceimpl PartialEq for ListRuleDeploymentsRequest
impl PartialEq for ListRuleDeploymentsRequest
Sourcefn eq(&self, other: &ListRuleDeploymentsRequest) -> bool
fn eq(&self, other: &ListRuleDeploymentsRequest) -> bool
self and other values to be equal, and is used by ==.