#[non_exhaustive]pub struct ListRuleRevisionsRequest {
pub name: String,
pub page_size: i32,
pub page_token: String,
pub view: RuleView,
/* private fields */
}Expand description
Request message for ListRuleRevisions method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The name of the rule to list revisions for.
Format:
projects/{project}/locations/{location}/instances/{instance}/rules/{rule}
page_size: i32The maximum number of revisions to return per page. The service may return fewer than this value. If unspecified, at most 100 revisions will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
page_token: StringThe page token, received from a previous ListRuleRevisions call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to ListRuleRevisions
must match the call that provided the page token.
view: RuleViewThe view field indicates the scope of fields to populate for the revision being returned. If unspecified, defaults to BASIC.
Implementations
Sourceimpl ListRuleRevisionsRequest
impl ListRuleRevisionsRequest
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListRuleRevisionsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListRuleRevisionsRequest
impl Clone for ListRuleRevisionsRequest
Sourcefn clone(&self) -> ListRuleRevisionsRequest
fn clone(&self) -> ListRuleRevisionsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ListRuleRevisionsRequest
impl Debug for ListRuleRevisionsRequest
Sourceimpl Default for ListRuleRevisionsRequest
impl Default for ListRuleRevisionsRequest
Sourcefn default() -> ListRuleRevisionsRequest
fn default() -> ListRuleRevisionsRequest
Sourceimpl Message for ListRuleRevisionsRequest
impl Message for ListRuleRevisionsRequest
Sourceimpl PartialEq for ListRuleRevisionsRequest
impl PartialEq for ListRuleRevisionsRequest
Sourcefn eq(&self, other: &ListRuleRevisionsRequest) -> bool
fn eq(&self, other: &ListRuleRevisionsRequest) -> bool
self and other values to be equal, and is used by ==.