#[non_exhaustive]pub struct ListRulesRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub view: RuleView,
pub filter: String,
/* private fields */
}Expand description
Request message for ListRules method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent, which owns this collection of rules.
Format:
projects/{project}/locations/{location}/instances/{instance}
page_size: i32The maximum number of rules to return. The service may return fewer than this value. If unspecified, at most 100 rules will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
page_token: StringA page token, received from a previous ListRules call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to ListRules
must match the call that provided the page token.
view: RuleViewview indicates the scope of fields to populate for the Rule being returned. If unspecified, defaults to BASIC.
filter: StringOnly the following filters are allowed: “reference_lists:{reference_list_name}” “data_tables:{data_table_name}” “display_name:{display_name}”
Implementations
Sourceimpl ListRulesRequest
impl ListRulesRequest