#[non_exhaustive]pub struct ListWatchlistsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
/* private fields */
}Expand description
Request message for listing watchlists.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent, which owns this collection of watchlists.
Format: projects/{project}/locations/{location}/instances/{instance}
page_size: i32Optional. The maximum number of watchlists to return. The service may return fewer than this value. If unspecified, at most 200 watchlists will be returned. The maximum value is 200; values above 200 will be coerced to 200.
page_token: StringOptional. A page token, received from a previous ListWatchlists call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to
ListWatchlists must match the call that provided the page
token.
filter: StringOptional. Which watchlist to return in aip.dev/160 form. Currently, only the following filters are supported:
watchlist_user_preferences.pinned=truehas_entity([ENTITY_INDICATOR],[ENTITY_TYPE])has_entity([ENTITY_INDICATOR],[ENTITY_TYPE],[NAMESPACE])
Implementations
Sourceimpl ListWatchlistsRequest
impl ListWatchlistsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListWatchlistsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListWatchlistsRequest
impl Clone for ListWatchlistsRequest
Sourcefn clone(&self) -> ListWatchlistsRequest
fn clone(&self) -> ListWatchlistsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ListWatchlistsRequest
impl Debug for ListWatchlistsRequest
Sourceimpl Default for ListWatchlistsRequest
impl Default for ListWatchlistsRequest
Sourcefn default() -> ListWatchlistsRequest
fn default() -> ListWatchlistsRequest
Sourceimpl Message for ListWatchlistsRequest
impl Message for ListWatchlistsRequest
Sourceimpl PartialEq for ListWatchlistsRequest
impl PartialEq for ListWatchlistsRequest
Sourcefn eq(&self, other: &ListWatchlistsRequest) -> bool
fn eq(&self, other: &ListWatchlistsRequest) -> bool
self and other values to be equal, and is used by ==.