#[non_exhaustive]pub struct ReferenceListScope {
pub scope_names: Vec<String>,
/* private fields */
}Expand description
ReferenceListScope specifies the list of scope names of the reference list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.scope_names: Vec<String>Optional. The list of scope names of the reference list. The scope names
should be full resource names and should be of the format:
projects/{project}/locations/{location}/instances/{instance}/dataAccessScopes/{scope_name}.
Implementations
Sourceimpl ReferenceListScope
impl ReferenceListScope
Sourcepub fn set_scope_names<T, V>(self, v: T) -> Self
pub fn set_scope_names<T, V>(self, v: T) -> Self
Sets the value of scope_names.
Example
ⓘ
let x = ReferenceListScope::new().set_scope_names(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ReferenceListScope
impl Clone for ReferenceListScope
Sourcefn clone(&self) -> ReferenceListScope
fn clone(&self) -> ReferenceListScope
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReferenceListScope
impl Debug for ReferenceListScope
Sourceimpl Default for ReferenceListScope
impl Default for ReferenceListScope
Sourcefn default() -> ReferenceListScope
fn default() -> ReferenceListScope
Returns the “default value” for a type. Read more
Sourceimpl Message for ReferenceListScope
impl Message for ReferenceListScope
Sourceimpl PartialEq for ReferenceListScope
impl PartialEq for ReferenceListScope
Sourcefn eq(&self, other: &ReferenceListScope) -> bool
fn eq(&self, other: &ReferenceListScope) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ReferenceListScope