#[non_exhaustive]pub struct UpdateDataAccessScopeRequest {
pub data_access_scope: Option<DataAccessScope>,
pub update_mask: Option<FieldMask>,
/* private fields */
}Expand description
Request message for UpdateDataAccessScope method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data_access_scope: Option<DataAccessScope>Required. The data access scope to update.
The scope’s name field is used to identify the scope to update.
Format:
projects/{project}/locations/{location}/instances/{instance}/dataAccessScopes/{data_access_scope}
update_mask: Option<FieldMask>The list of fields to update. If not included, all fields with a non-empty value will be overwritten. Currently, only the description, the allowed and denied labels list fields are supported for update; an update call that attempts to update any other fields will return INVALID_ARGUMENT.
Implementations
Sourceimpl UpdateDataAccessScopeRequest
impl UpdateDataAccessScopeRequest
Sourcepub fn set_data_access_scope<T>(self, v: T) -> Selfwhere
T: Into<DataAccessScope>,
pub fn set_data_access_scope<T>(self, v: T) -> Selfwhere
T: Into<DataAccessScope>,
Sets the value of data_access_scope.
Example
ⓘ
use google_cloud_chronicle_v1::model::DataAccessScope;
let x = UpdateDataAccessScopeRequest::new().set_data_access_scope(DataAccessScope::default()/* use setters */);Sourcepub fn set_or_clear_data_access_scope<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataAccessScope>,
pub fn set_or_clear_data_access_scope<T>(self, v: Option<T>) -> Selfwhere
T: Into<DataAccessScope>,
Sets or clears the value of data_access_scope.
Example
ⓘ
use google_cloud_chronicle_v1::model::DataAccessScope;
let x = UpdateDataAccessScopeRequest::new().set_or_clear_data_access_scope(Some(DataAccessScope::default()/* use setters */));
let x = UpdateDataAccessScopeRequest::new().set_or_clear_data_access_scope(None::<DataAccessScope>);Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateDataAccessScopeRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateDataAccessScopeRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateDataAccessScopeRequest::new().set_or_clear_update_mask(None::<FieldMask>);Trait Implementations
Sourceimpl Clone for UpdateDataAccessScopeRequest
impl Clone for UpdateDataAccessScopeRequest
Sourcefn clone(&self) -> UpdateDataAccessScopeRequest
fn clone(&self) -> UpdateDataAccessScopeRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateDataAccessScopeRequest
impl Debug for UpdateDataAccessScopeRequest
Sourceimpl Default for UpdateDataAccessScopeRequest
impl Default for UpdateDataAccessScopeRequest
Sourcefn default() -> UpdateDataAccessScopeRequest
fn default() -> UpdateDataAccessScopeRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for UpdateDataAccessScopeRequest
impl PartialEq for UpdateDataAccessScopeRequest
Sourcefn eq(&self, other: &UpdateDataAccessScopeRequest) -> bool
fn eq(&self, other: &UpdateDataAccessScopeRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateDataAccessScopeRequest