#[non_exhaustive]pub struct UpdateReferenceListRequest {
pub reference_list: Option<ReferenceList>,
pub update_mask: Option<FieldMask>,
/* private fields */
}Expand description
A request to update a reference list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.reference_list: Option<ReferenceList>Required. The reference list to update.
The reference list’s name field is used to identify the reference list to
update.
Format:
projects/{project}/locations/{locations}/instances/{instance}/referenceLists/{reference_list}
update_mask: Option<FieldMask>The list of fields to update. When no field mask is supplied, all non-empty fields will be updated. A field mask of “*” will update all fields, whether empty or not.
Implementations
Sourceimpl UpdateReferenceListRequest
impl UpdateReferenceListRequest
Sourcepub fn set_reference_list<T>(self, v: T) -> Selfwhere
T: Into<ReferenceList>,
pub fn set_reference_list<T>(self, v: T) -> Selfwhere
T: Into<ReferenceList>,
Sets the value of reference_list.
Example
ⓘ
use google_cloud_chronicle_v1::model::ReferenceList;
let x = UpdateReferenceListRequest::new().set_reference_list(ReferenceList::default()/* use setters */);Sourcepub fn set_or_clear_reference_list<T>(self, v: Option<T>) -> Selfwhere
T: Into<ReferenceList>,
pub fn set_or_clear_reference_list<T>(self, v: Option<T>) -> Selfwhere
T: Into<ReferenceList>,
Sets or clears the value of reference_list.
Example
ⓘ
use google_cloud_chronicle_v1::model::ReferenceList;
let x = UpdateReferenceListRequest::new().set_or_clear_reference_list(Some(ReferenceList::default()/* use setters */));
let x = UpdateReferenceListRequest::new().set_or_clear_reference_list(None::<ReferenceList>);Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateReferenceListRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateReferenceListRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateReferenceListRequest::new().set_or_clear_update_mask(None::<FieldMask>);Trait Implementations
Sourceimpl Clone for UpdateReferenceListRequest
impl Clone for UpdateReferenceListRequest
Sourcefn clone(&self) -> UpdateReferenceListRequest
fn clone(&self) -> UpdateReferenceListRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateReferenceListRequest
impl Debug for UpdateReferenceListRequest
Sourceimpl Default for UpdateReferenceListRequest
impl Default for UpdateReferenceListRequest
Sourcefn default() -> UpdateReferenceListRequest
fn default() -> UpdateReferenceListRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for UpdateReferenceListRequest
impl Message for UpdateReferenceListRequest
Sourceimpl PartialEq for UpdateReferenceListRequest
impl PartialEq for UpdateReferenceListRequest
Sourcefn eq(&self, other: &UpdateReferenceListRequest) -> bool
fn eq(&self, other: &UpdateReferenceListRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateReferenceListRequest