#[non_exhaustive]pub struct UpdateRuleDeploymentRequest {
pub rule_deployment: Option<RuleDeployment>,
pub update_mask: Option<FieldMask>,
/* private fields */
}Expand description
Request message for UpdateRuleDeployment.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rule_deployment: Option<RuleDeployment>Required. The rule deployment to update.
The rule deployment’s name field is used to identify the rule deployment
to update. Format:
projects/{project}/locations/{location}/instances/{instance}/rules/{rule}/deployment
update_mask: Option<FieldMask>Required. The list of fields to update.
Implementations
Sourceimpl UpdateRuleDeploymentRequest
impl UpdateRuleDeploymentRequest
Sourcepub fn set_rule_deployment<T>(self, v: T) -> Selfwhere
T: Into<RuleDeployment>,
pub fn set_rule_deployment<T>(self, v: T) -> Selfwhere
T: Into<RuleDeployment>,
Sets the value of rule_deployment.
Example
ⓘ
use google_cloud_chronicle_v1::model::RuleDeployment;
let x = UpdateRuleDeploymentRequest::new().set_rule_deployment(RuleDeployment::default()/* use setters */);Sourcepub fn set_or_clear_rule_deployment<T>(self, v: Option<T>) -> Selfwhere
T: Into<RuleDeployment>,
pub fn set_or_clear_rule_deployment<T>(self, v: Option<T>) -> Selfwhere
T: Into<RuleDeployment>,
Sets or clears the value of rule_deployment.
Example
ⓘ
use google_cloud_chronicle_v1::model::RuleDeployment;
let x = UpdateRuleDeploymentRequest::new().set_or_clear_rule_deployment(Some(RuleDeployment::default()/* use setters */));
let x = UpdateRuleDeploymentRequest::new().set_or_clear_rule_deployment(None::<RuleDeployment>);Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateRuleDeploymentRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateRuleDeploymentRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateRuleDeploymentRequest::new().set_or_clear_update_mask(None::<FieldMask>);Trait Implementations
Sourceimpl Clone for UpdateRuleDeploymentRequest
impl Clone for UpdateRuleDeploymentRequest
Sourcefn clone(&self) -> UpdateRuleDeploymentRequest
fn clone(&self) -> UpdateRuleDeploymentRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateRuleDeploymentRequest
impl Debug for UpdateRuleDeploymentRequest
Sourceimpl Default for UpdateRuleDeploymentRequest
impl Default for UpdateRuleDeploymentRequest
Sourcefn default() -> UpdateRuleDeploymentRequest
fn default() -> UpdateRuleDeploymentRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for UpdateRuleDeploymentRequest
impl PartialEq for UpdateRuleDeploymentRequest
Sourcefn eq(&self, other: &UpdateRuleDeploymentRequest) -> bool
fn eq(&self, other: &UpdateRuleDeploymentRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateRuleDeploymentRequest