#[non_exhaustive]pub struct UpdateRuleRequest {
pub rule: Option<Rule>,
pub update_mask: Option<FieldMask>,
/* private fields */
}Expand description
Request message for UpdateRule method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rule: Option<Rule>Required. The rule to update.
The rule’s name field is used to identify the rule to update.
Format:
projects/{project}/locations/{location}/instances/{instance}/rules/{rule}
update_mask: Option<FieldMask>The list of fields to update. If not included, all fields with a non-empty value will be overwritten.
Implementations
Sourceimpl UpdateRuleRequest
impl UpdateRuleRequest
Sourcepub fn set_or_clear_rule<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_rule<T>(self, v: Option<T>) -> Self
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateRuleRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateRuleRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateRuleRequest::new().set_or_clear_update_mask(None::<FieldMask>);Trait Implementations
Sourceimpl Clone for UpdateRuleRequest
impl Clone for UpdateRuleRequest
Sourcefn clone(&self) -> UpdateRuleRequest
fn clone(&self) -> UpdateRuleRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateRuleRequest
impl Debug for UpdateRuleRequest
Sourceimpl Default for UpdateRuleRequest
impl Default for UpdateRuleRequest
Sourcefn default() -> UpdateRuleRequest
fn default() -> UpdateRuleRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for UpdateRuleRequest
impl Message for UpdateRuleRequest
Sourceimpl PartialEq for UpdateRuleRequest
impl PartialEq for UpdateRuleRequest
Sourcefn eq(&self, other: &UpdateRuleRequest) -> bool
fn eq(&self, other: &UpdateRuleRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateRuleRequest