#[non_exhaustive]pub struct UpdateWatchlistRequest {
pub watchlist: Option<Watchlist>,
pub update_mask: Option<FieldMask>,
/* private fields */
}Expand description
Request message for updating watchlist.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.watchlist: Option<Watchlist>Required. The watchlist to update.
The watchlist’s name field is used to identify the watchlist to update.
Format:
projects/{project}/locations/{location}/instances/{instance}/watchlists/{watchlist}
update_mask: Option<FieldMask>Optional. The list of fields to update.
Implementations
Sourceimpl UpdateWatchlistRequest
impl UpdateWatchlistRequest
Sourcepub fn set_watchlist<T>(self, v: T) -> Self
pub fn set_watchlist<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_watchlist<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_watchlist<T>(self, v: Option<T>) -> Self
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateWatchlistRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateWatchlistRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateWatchlistRequest::new().set_or_clear_update_mask(None::<FieldMask>);Trait Implementations
Sourceimpl Clone for UpdateWatchlistRequest
impl Clone for UpdateWatchlistRequest
Sourcefn clone(&self) -> UpdateWatchlistRequest
fn clone(&self) -> UpdateWatchlistRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateWatchlistRequest
impl Debug for UpdateWatchlistRequest
Sourceimpl Default for UpdateWatchlistRequest
impl Default for UpdateWatchlistRequest
Sourcefn default() -> UpdateWatchlistRequest
fn default() -> UpdateWatchlistRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for UpdateWatchlistRequest
impl Message for UpdateWatchlistRequest
Sourceimpl PartialEq for UpdateWatchlistRequest
impl PartialEq for UpdateWatchlistRequest
Sourcefn eq(&self, other: &UpdateWatchlistRequest) -> bool
fn eq(&self, other: &UpdateWatchlistRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateWatchlistRequest