#[non_exhaustive]pub struct Visualization {Show 14 fields
pub x_axes: Vec<Axis>,
pub y_axes: Vec<Axis>,
pub series: Vec<Series>,
pub tooltip: Option<Tooltip>,
pub legends: Vec<Legend>,
pub column_defs: Vec<ColumnDef>,
pub table_config: Option<TableConfig>,
pub button: Option<Button>,
pub markdown: Option<Markdown>,
pub series_column: Vec<String>,
pub grouping_type: String,
pub google_maps_config: Option<GoogleMapsConfig>,
pub threshold_coloring_enabled: bool,
pub visual_maps: Vec<VisualMap>,
/* private fields */
}Expand description
Visualization config for a chart. https://echarts.apache.org/en/option.html#series
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.x_axes: Vec<Axis>y_axes: Vec<Axis>series: Vec<Series>tooltip: Option<Tooltip>legends: Vec<Legend>column_defs: Vec<ColumnDef>Column Definition to represent chart as a table.
table_config: Option<TableConfig>Optional. Configuration for table appearance.
Button config for a chart if tileType is TILE_TYPE_BUTTON.
markdown: Option<Markdown>Optional. Markdown config for a chart if tileType is TILE_TYPE_MARKDOWN.
series_column: Vec<String>Optional. Selected column for series
grouping_type: StringOptional. Selected grouping type for series
google_maps_config: Option<GoogleMapsConfig>Optional. Google Maps config for a chart if type is GOOGLE MAPS.
threshold_coloring_enabled: boolOptional. Whether threshold coloring is enabled for the chart. If it’s enabled, the chart will be colored based on the values stored in VisualMap below.
visual_maps: Vec<VisualMap>Optional. Visual maps for the chart.
Implementations
Sourceimpl Visualization
impl Visualization
Sourcepub fn set_x_axes<T, V>(self, v: T) -> Self
pub fn set_x_axes<T, V>(self, v: T) -> Self
Sourcepub fn set_y_axes<T, V>(self, v: T) -> Self
pub fn set_y_axes<T, V>(self, v: T) -> Self
Sourcepub fn set_series<T, V>(self, v: T) -> Self
pub fn set_series<T, V>(self, v: T) -> Self
Sourcepub fn set_tooltip<T>(self, v: T) -> Self
pub fn set_tooltip<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_tooltip<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_tooltip<T>(self, v: Option<T>) -> Self
Sourcepub fn set_legends<T, V>(self, v: T) -> Self
pub fn set_legends<T, V>(self, v: T) -> Self
Sourcepub fn set_column_defs<T, V>(self, v: T) -> Self
pub fn set_column_defs<T, V>(self, v: T) -> Self
Sets the value of column_defs.
Example
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::ColumnDef;
let x = Visualization::new()
.set_column_defs([
ColumnDef::default()/* use setters */,
ColumnDef::default()/* use (different) setters */,
]);Sourcepub fn set_table_config<T>(self, v: T) -> Selfwhere
T: Into<TableConfig>,
pub fn set_table_config<T>(self, v: T) -> Selfwhere
T: Into<TableConfig>,
Sets the value of table_config.
Example
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::TableConfig;
let x = Visualization::new().set_table_config(TableConfig::default()/* use setters */);Sourcepub fn set_or_clear_table_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableConfig>,
pub fn set_or_clear_table_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<TableConfig>,
Sets or clears the value of table_config.
Example
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::TableConfig;
let x = Visualization::new().set_or_clear_table_config(Some(TableConfig::default()/* use setters */));
let x = Visualization::new().set_or_clear_table_config(None::<TableConfig>);Sourcepub fn set_markdown<T>(self, v: T) -> Self
pub fn set_markdown<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_markdown<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_markdown<T>(self, v: Option<T>) -> Self
Sourcepub fn set_series_column<T, V>(self, v: T) -> Self
pub fn set_series_column<T, V>(self, v: T) -> Self
Sets the value of series_column.
Example
let x = Visualization::new().set_series_column(["a", "b", "c"]);Sourcepub fn set_grouping_type<T: Into<String>>(self, v: T) -> Self
pub fn set_grouping_type<T: Into<String>>(self, v: T) -> Self
Sets the value of grouping_type.
Example
let x = Visualization::new().set_grouping_type("example");Sourcepub fn set_google_maps_config<T>(self, v: T) -> Selfwhere
T: Into<GoogleMapsConfig>,
pub fn set_google_maps_config<T>(self, v: T) -> Selfwhere
T: Into<GoogleMapsConfig>,
Sets the value of google_maps_config.
Example
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::GoogleMapsConfig;
let x = Visualization::new().set_google_maps_config(GoogleMapsConfig::default()/* use setters */);Sourcepub fn set_or_clear_google_maps_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<GoogleMapsConfig>,
pub fn set_or_clear_google_maps_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<GoogleMapsConfig>,
Sets or clears the value of google_maps_config.
Example
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::GoogleMapsConfig;
let x = Visualization::new().set_or_clear_google_maps_config(Some(GoogleMapsConfig::default()/* use setters */));
let x = Visualization::new().set_or_clear_google_maps_config(None::<GoogleMapsConfig>);Sourcepub fn set_threshold_coloring_enabled<T: Into<bool>>(self, v: T) -> Self
pub fn set_threshold_coloring_enabled<T: Into<bool>>(self, v: T) -> Self
Sets the value of threshold_coloring_enabled.
Example
let x = Visualization::new().set_threshold_coloring_enabled(true);Sourcepub fn set_visual_maps<T, V>(self, v: T) -> Self
pub fn set_visual_maps<T, V>(self, v: T) -> Self
Sets the value of visual_maps.
Example
use google_cloud_chronicle_v1::model::dashboard_chart::visualization::VisualMap;
let x = Visualization::new()
.set_visual_maps([
VisualMap::default()/* use setters */,
VisualMap::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for Visualization
impl Clone for Visualization
Sourcefn clone(&self) -> Visualization
fn clone(&self) -> Visualization
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for Visualization
impl Debug for Visualization
Sourceimpl Default for Visualization
impl Default for Visualization
Sourcefn default() -> Visualization
fn default() -> Visualization
Sourceimpl Message for Visualization
impl Message for Visualization
Sourceimpl PartialEq for Visualization
impl PartialEq for Visualization
Sourcefn eq(&self, other: &Visualization) -> bool
fn eq(&self, other: &Visualization) -> bool
self and other values to be equal, and is used by ==.