#[non_exhaustive]pub struct ColumnValue {
pub metadata: Option<ValueMetadata>,
pub value: Option<Value>,
/* private fields */
}Expand description
LINT.IfChange(stats_data) Value of the column based on data type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.metadata: Option<ValueMetadata>value: Option<Value>Implementations
Sourceimpl ColumnValue
impl ColumnValue
Sourcepub fn set_metadata<T>(self, v: T) -> Selfwhere
T: Into<ValueMetadata>,
pub fn set_metadata<T>(self, v: T) -> Selfwhere
T: Into<ValueMetadata>,
Sourcepub fn set_or_clear_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<ValueMetadata>,
pub fn set_or_clear_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<ValueMetadata>,
Sets or clears the value of metadata.
Example
use google_cloud_chronicle_v1::model::execute_dashboard_query_response::column_value::ValueMetadata;
let x = ColumnValue::new().set_or_clear_metadata(Some(ValueMetadata::default()/* use setters */));
let x = ColumnValue::new().set_or_clear_metadata(None::<ValueMetadata>);Sourcepub fn null_val(&self) -> Option<&bool>
pub fn null_val(&self) -> Option<&bool>
The value of value
if it holds a NullVal, None if the field is not set or
holds a different branch.
Sourcepub fn set_null_val<T: Into<bool>>(self, v: T) -> Self
pub fn set_null_val<T: Into<bool>>(self, v: T) -> Self
Sets the value of value
to hold a NullVal.
Note that all the setters affecting value are
mutually exclusive.
Example
let x = ColumnValue::new().set_null_val(true);
assert!(x.null_val().is_some());
assert!(x.bool_val().is_none());
assert!(x.bytes_val().is_none());
assert!(x.double_val().is_none());
assert!(x.int64_val().is_none());
assert!(x.uint64_val().is_none());
assert!(x.string_val().is_none());
assert!(x.timestamp_val().is_none());
assert!(x.date_val().is_none());
assert!(x.proto_val().is_none());Sourcepub fn bool_val(&self) -> Option<&bool>
pub fn bool_val(&self) -> Option<&bool>
The value of value
if it holds a BoolVal, None if the field is not set or
holds a different branch.
Sourcepub fn set_bool_val<T: Into<bool>>(self, v: T) -> Self
pub fn set_bool_val<T: Into<bool>>(self, v: T) -> Self
Sets the value of value
to hold a BoolVal.
Note that all the setters affecting value are
mutually exclusive.
Example
let x = ColumnValue::new().set_bool_val(true);
assert!(x.bool_val().is_some());
assert!(x.null_val().is_none());
assert!(x.bytes_val().is_none());
assert!(x.double_val().is_none());
assert!(x.int64_val().is_none());
assert!(x.uint64_val().is_none());
assert!(x.string_val().is_none());
assert!(x.timestamp_val().is_none());
assert!(x.date_val().is_none());
assert!(x.proto_val().is_none());Sourcepub fn bytes_val(&self) -> Option<&Bytes>
pub fn bytes_val(&self) -> Option<&Bytes>
The value of value
if it holds a BytesVal, None if the field is not set or
holds a different branch.
Sourcepub fn set_bytes_val<T: Into<Bytes>>(self, v: T) -> Self
pub fn set_bytes_val<T: Into<Bytes>>(self, v: T) -> Self
Sets the value of value
to hold a BytesVal.
Note that all the setters affecting value are
mutually exclusive.
Example
let x = ColumnValue::new().set_bytes_val(bytes::Bytes::from_static(b"example"));
assert!(x.bytes_val().is_some());
assert!(x.null_val().is_none());
assert!(x.bool_val().is_none());
assert!(x.double_val().is_none());
assert!(x.int64_val().is_none());
assert!(x.uint64_val().is_none());
assert!(x.string_val().is_none());
assert!(x.timestamp_val().is_none());
assert!(x.date_val().is_none());
assert!(x.proto_val().is_none());Sourcepub fn double_val(&self) -> Option<&f64>
pub fn double_val(&self) -> Option<&f64>
The value of value
if it holds a DoubleVal, None if the field is not set or
holds a different branch.
Sourcepub fn set_double_val<T: Into<f64>>(self, v: T) -> Self
pub fn set_double_val<T: Into<f64>>(self, v: T) -> Self
Sets the value of value
to hold a DoubleVal.
Note that all the setters affecting value are
mutually exclusive.
Example
let x = ColumnValue::new().set_double_val(42.0);
assert!(x.double_val().is_some());
assert!(x.null_val().is_none());
assert!(x.bool_val().is_none());
assert!(x.bytes_val().is_none());
assert!(x.int64_val().is_none());
assert!(x.uint64_val().is_none());
assert!(x.string_val().is_none());
assert!(x.timestamp_val().is_none());
assert!(x.date_val().is_none());
assert!(x.proto_val().is_none());Sourcepub fn int64_val(&self) -> Option<&i64>
pub fn int64_val(&self) -> Option<&i64>
The value of value
if it holds a Int64Val, None if the field is not set or
holds a different branch.
Sourcepub fn set_int64_val<T: Into<i64>>(self, v: T) -> Self
pub fn set_int64_val<T: Into<i64>>(self, v: T) -> Self
Sets the value of value
to hold a Int64Val.
Note that all the setters affecting value are
mutually exclusive.
Example
let x = ColumnValue::new().set_int64_val(42);
assert!(x.int64_val().is_some());
assert!(x.null_val().is_none());
assert!(x.bool_val().is_none());
assert!(x.bytes_val().is_none());
assert!(x.double_val().is_none());
assert!(x.uint64_val().is_none());
assert!(x.string_val().is_none());
assert!(x.timestamp_val().is_none());
assert!(x.date_val().is_none());
assert!(x.proto_val().is_none());Sourcepub fn uint64_val(&self) -> Option<&u64>
pub fn uint64_val(&self) -> Option<&u64>
The value of value
if it holds a Uint64Val, None if the field is not set or
holds a different branch.
Sourcepub fn set_uint64_val<T: Into<u64>>(self, v: T) -> Self
pub fn set_uint64_val<T: Into<u64>>(self, v: T) -> Self
Sets the value of value
to hold a Uint64Val.
Note that all the setters affecting value are
mutually exclusive.
Example
let x = ColumnValue::new().set_uint64_val(42_u32);
assert!(x.uint64_val().is_some());
assert!(x.null_val().is_none());
assert!(x.bool_val().is_none());
assert!(x.bytes_val().is_none());
assert!(x.double_val().is_none());
assert!(x.int64_val().is_none());
assert!(x.string_val().is_none());
assert!(x.timestamp_val().is_none());
assert!(x.date_val().is_none());
assert!(x.proto_val().is_none());Sourcepub fn string_val(&self) -> Option<&String>
pub fn string_val(&self) -> Option<&String>
The value of value
if it holds a StringVal, None if the field is not set or
holds a different branch.
Sourcepub fn set_string_val<T: Into<String>>(self, v: T) -> Self
pub fn set_string_val<T: Into<String>>(self, v: T) -> Self
Sets the value of value
to hold a StringVal.
Note that all the setters affecting value are
mutually exclusive.
Example
let x = ColumnValue::new().set_string_val("example");
assert!(x.string_val().is_some());
assert!(x.null_val().is_none());
assert!(x.bool_val().is_none());
assert!(x.bytes_val().is_none());
assert!(x.double_val().is_none());
assert!(x.int64_val().is_none());
assert!(x.uint64_val().is_none());
assert!(x.timestamp_val().is_none());
assert!(x.date_val().is_none());
assert!(x.proto_val().is_none());Sourcepub fn timestamp_val(&self) -> Option<&Box<Timestamp>>
pub fn timestamp_val(&self) -> Option<&Box<Timestamp>>
The value of value
if it holds a TimestampVal, None if the field is not set or
holds a different branch.
Sourcepub fn set_timestamp_val<T: Into<Box<Timestamp>>>(self, v: T) -> Self
pub fn set_timestamp_val<T: Into<Box<Timestamp>>>(self, v: T) -> Self
Sets the value of value
to hold a TimestampVal.
Note that all the setters affecting value are
mutually exclusive.
Example
use wkt::Timestamp;
let x = ColumnValue::new().set_timestamp_val(Timestamp::default()/* use setters */);
assert!(x.timestamp_val().is_some());
assert!(x.null_val().is_none());
assert!(x.bool_val().is_none());
assert!(x.bytes_val().is_none());
assert!(x.double_val().is_none());
assert!(x.int64_val().is_none());
assert!(x.uint64_val().is_none());
assert!(x.string_val().is_none());
assert!(x.date_val().is_none());
assert!(x.proto_val().is_none());Sourcepub fn date_val(&self) -> Option<&Box<Date>>
pub fn date_val(&self) -> Option<&Box<Date>>
The value of value
if it holds a DateVal, None if the field is not set or
holds a different branch.
Sourcepub fn set_date_val<T: Into<Box<Date>>>(self, v: T) -> Self
pub fn set_date_val<T: Into<Box<Date>>>(self, v: T) -> Self
Sets the value of value
to hold a DateVal.
Note that all the setters affecting value are
mutually exclusive.
Example
use google_cloud_type::model::Date;
let x = ColumnValue::new().set_date_val(Date::default()/* use setters */);
assert!(x.date_val().is_some());
assert!(x.null_val().is_none());
assert!(x.bool_val().is_none());
assert!(x.bytes_val().is_none());
assert!(x.double_val().is_none());
assert!(x.int64_val().is_none());
assert!(x.uint64_val().is_none());
assert!(x.string_val().is_none());
assert!(x.timestamp_val().is_none());
assert!(x.proto_val().is_none());Sourcepub fn proto_val(&self) -> Option<&Box<Any>>
pub fn proto_val(&self) -> Option<&Box<Any>>
The value of value
if it holds a ProtoVal, None if the field is not set or
holds a different branch.
Sourcepub fn set_proto_val<T: Into<Box<Any>>>(self, v: T) -> Self
pub fn set_proto_val<T: Into<Box<Any>>>(self, v: T) -> Self
Sets the value of value
to hold a ProtoVal.
Note that all the setters affecting value are
mutually exclusive.
Example
use wkt::Any;
let x = ColumnValue::new().set_proto_val(Any::default()/* use setters */);
assert!(x.proto_val().is_some());
assert!(x.null_val().is_none());
assert!(x.bool_val().is_none());
assert!(x.bytes_val().is_none());
assert!(x.double_val().is_none());
assert!(x.int64_val().is_none());
assert!(x.uint64_val().is_none());
assert!(x.string_val().is_none());
assert!(x.timestamp_val().is_none());
assert!(x.date_val().is_none());Trait Implementations
Sourceimpl Clone for ColumnValue
impl Clone for ColumnValue
Sourcefn clone(&self) -> ColumnValue
fn clone(&self) -> ColumnValue
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ColumnValue
impl Debug for ColumnValue
Sourceimpl Default for ColumnValue
impl Default for ColumnValue
Sourcefn default() -> ColumnValue
fn default() -> ColumnValue
Sourceimpl Message for ColumnValue
impl Message for ColumnValue
Sourceimpl PartialEq for ColumnValue
impl PartialEq for ColumnValue
Sourcefn eq(&self, other: &ColumnValue) -> bool
fn eq(&self, other: &ColumnValue) -> bool
self and other values to be equal, and is used by ==.