#[non_exhaustive]pub struct ColumnMetadata {
pub column: String,
pub field_path: String,
pub function_name: String,
pub function_module: String,
pub data_source: DataSource,
pub timestamp_metadata: Option<TimestampMetadata>,
pub longitude: bool,
pub latitude: bool,
pub selected: bool,
pub unselected: bool,
/* private fields */
}Expand description
Metadata of the column.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.column: StringName of the column.
field_path: StringField path of the queried field, if any.
function_name: StringName of the function used to query the field, if any.
function_module: StringModule of the function used to query the field, if any.
data_source: DataSourceData source queried.
timestamp_metadata: Option<TimestampMetadata>Timestamp Metadata
longitude: boolWhether the column is a longitude field.
latitude: boolWhether the column is a latitude field.
selected: boolWhether the column is selected in the final response.
unselected: boolWhether the column is unselected in the final response.
Implementations
Sourceimpl ColumnMetadata
impl ColumnMetadata
Sourcepub fn set_column<T: Into<String>>(self, v: T) -> Self
pub fn set_column<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_field_path<T: Into<String>>(self, v: T) -> Self
pub fn set_field_path<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_function_name<T: Into<String>>(self, v: T) -> Self
pub fn set_function_name<T: Into<String>>(self, v: T) -> Self
Sets the value of function_name.
Example
ⓘ
let x = ColumnMetadata::new().set_function_name("example");Sourcepub fn set_function_module<T: Into<String>>(self, v: T) -> Self
pub fn set_function_module<T: Into<String>>(self, v: T) -> Self
Sets the value of function_module.
Example
ⓘ
let x = ColumnMetadata::new().set_function_module("example");Sourcepub fn set_data_source<T: Into<DataSource>>(self, v: T) -> Self
pub fn set_data_source<T: Into<DataSource>>(self, v: T) -> Self
Sets the value of data_source.
Example
ⓘ
use google_cloud_chronicle_v1::model::DataSource;
let x0 = ColumnMetadata::new().set_data_source(DataSource::Udm);
let x1 = ColumnMetadata::new().set_data_source(DataSource::Entity);
let x2 = ColumnMetadata::new().set_data_source(DataSource::IngestionMetrics);Sourcepub fn set_timestamp_metadata<T>(self, v: T) -> Selfwhere
T: Into<TimestampMetadata>,
pub fn set_timestamp_metadata<T>(self, v: T) -> Selfwhere
T: Into<TimestampMetadata>,
Sets the value of timestamp_metadata.
Example
ⓘ
use google_cloud_chronicle_v1::model::TimestampMetadata;
let x = ColumnMetadata::new().set_timestamp_metadata(TimestampMetadata::default()/* use setters */);Sourcepub fn set_or_clear_timestamp_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<TimestampMetadata>,
pub fn set_or_clear_timestamp_metadata<T>(self, v: Option<T>) -> Selfwhere
T: Into<TimestampMetadata>,
Sets or clears the value of timestamp_metadata.
Example
ⓘ
use google_cloud_chronicle_v1::model::TimestampMetadata;
let x = ColumnMetadata::new().set_or_clear_timestamp_metadata(Some(TimestampMetadata::default()/* use setters */));
let x = ColumnMetadata::new().set_or_clear_timestamp_metadata(None::<TimestampMetadata>);Sourcepub fn set_longitude<T: Into<bool>>(self, v: T) -> Self
pub fn set_longitude<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_latitude<T: Into<bool>>(self, v: T) -> Self
pub fn set_latitude<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_selected<T: Into<bool>>(self, v: T) -> Self
pub fn set_selected<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_unselected<T: Into<bool>>(self, v: T) -> Self
pub fn set_unselected<T: Into<bool>>(self, v: T) -> Self