#[non_exhaustive]pub struct DataAccessLabelReference {
pub display_name: String,
pub label: Option<Label>,
/* private fields */
}Expand description
Reference object to a data access label.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.display_name: StringOutput only. The display name of the label. Data access label and log types’s name will match the display name of the resource. The asset namespace will match the namespace itself. The ingestion key value pair will match the key of the tuple.
label: Option<Label>The unique identifier for the label.
Implementations
Sourceimpl DataAccessLabelReference
impl DataAccessLabelReference
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
let x = DataAccessLabelReference::new().set_display_name("example");Sourcepub fn data_access_label(&self) -> Option<&String>
pub fn data_access_label(&self) -> Option<&String>
The value of label
if it holds a DataAccessLabel, None if the field is not set or
holds a different branch.
Sourcepub fn set_data_access_label<T: Into<String>>(self, v: T) -> Self
pub fn set_data_access_label<T: Into<String>>(self, v: T) -> Self
Sets the value of label
to hold a DataAccessLabel.
Note that all the setters affecting label are
mutually exclusive.
Example
let x = DataAccessLabelReference::new().set_data_access_label("example");
assert!(x.data_access_label().is_some());
assert!(x.log_type().is_none());
assert!(x.asset_namespace().is_none());
assert!(x.ingestion_label().is_none());Sourcepub fn log_type(&self) -> Option<&String>
pub fn log_type(&self) -> Option<&String>
The value of label
if it holds a LogType, None if the field is not set or
holds a different branch.
Sourcepub fn set_log_type<T: Into<String>>(self, v: T) -> Self
pub fn set_log_type<T: Into<String>>(self, v: T) -> Self
Sets the value of label
to hold a LogType.
Note that all the setters affecting label are
mutually exclusive.
Example
let x = DataAccessLabelReference::new().set_log_type("example");
assert!(x.log_type().is_some());
assert!(x.data_access_label().is_none());
assert!(x.asset_namespace().is_none());
assert!(x.ingestion_label().is_none());Sourcepub fn asset_namespace(&self) -> Option<&String>
pub fn asset_namespace(&self) -> Option<&String>
The value of label
if it holds a AssetNamespace, None if the field is not set or
holds a different branch.
Sourcepub fn set_asset_namespace<T: Into<String>>(self, v: T) -> Self
pub fn set_asset_namespace<T: Into<String>>(self, v: T) -> Self
Sets the value of label
to hold a AssetNamespace.
Note that all the setters affecting label are
mutually exclusive.
Example
let x = DataAccessLabelReference::new().set_asset_namespace("example");
assert!(x.asset_namespace().is_some());
assert!(x.data_access_label().is_none());
assert!(x.log_type().is_none());
assert!(x.ingestion_label().is_none());Sourcepub fn ingestion_label(&self) -> Option<&Box<IngestionLabel>>
pub fn ingestion_label(&self) -> Option<&Box<IngestionLabel>>
The value of label
if it holds a IngestionLabel, None if the field is not set or
holds a different branch.
Sourcepub fn set_ingestion_label<T: Into<Box<IngestionLabel>>>(self, v: T) -> Self
pub fn set_ingestion_label<T: Into<Box<IngestionLabel>>>(self, v: T) -> Self
Sets the value of label
to hold a IngestionLabel.
Note that all the setters affecting label are
mutually exclusive.
Example
use google_cloud_chronicle_v1::model::IngestionLabel;
let x = DataAccessLabelReference::new().set_ingestion_label(IngestionLabel::default()/* use setters */);
assert!(x.ingestion_label().is_some());
assert!(x.data_access_label().is_none());
assert!(x.log_type().is_none());
assert!(x.asset_namespace().is_none());Trait Implementations
Sourceimpl Clone for DataAccessLabelReference
impl Clone for DataAccessLabelReference
Sourcefn clone(&self) -> DataAccessLabelReference
fn clone(&self) -> DataAccessLabelReference
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for DataAccessLabelReference
impl Debug for DataAccessLabelReference
Sourceimpl Default for DataAccessLabelReference
impl Default for DataAccessLabelReference
Sourcefn default() -> DataAccessLabelReference
fn default() -> DataAccessLabelReference
Sourceimpl Message for DataAccessLabelReference
impl Message for DataAccessLabelReference
Sourceimpl PartialEq for DataAccessLabelReference
impl PartialEq for DataAccessLabelReference
Sourcefn eq(&self, other: &DataAccessLabelReference) -> bool
fn eq(&self, other: &DataAccessLabelReference) -> bool
self and other values to be equal, and is used by ==.