#[non_exhaustive]pub struct DataTableScopeInfo {
pub data_access_scopes: Vec<String>,
/* private fields */
}Expand description
DataTableScopeInfo specifies the scope info of the data table.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data_access_scopes: Vec<String>Required. Contains the list of scope names of the data table. If the list is empty, the data table is treated as unscoped. The scope names should be full resource names and should be of the format: “projects/{project}/locations/{location}/instances/{instance}/dataAccessScopes/{scope_name}”
Implementations
Sourceimpl DataTableScopeInfo
impl DataTableScopeInfo
Sourcepub fn set_data_access_scopes<T, V>(self, v: T) -> Self
pub fn set_data_access_scopes<T, V>(self, v: T) -> Self
Sets the value of data_access_scopes.
Example
ⓘ
let x = DataTableScopeInfo::new().set_data_access_scopes(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for DataTableScopeInfo
impl Clone for DataTableScopeInfo
Sourcefn clone(&self) -> DataTableScopeInfo
fn clone(&self) -> DataTableScopeInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DataTableScopeInfo
impl Debug for DataTableScopeInfo
Sourceimpl Default for DataTableScopeInfo
impl Default for DataTableScopeInfo
Sourcefn default() -> DataTableScopeInfo
fn default() -> DataTableScopeInfo
Returns the “default value” for a type. Read more
Sourceimpl Message for DataTableScopeInfo
impl Message for DataTableScopeInfo
Sourceimpl PartialEq for DataTableScopeInfo
impl PartialEq for DataTableScopeInfo
impl StructuralPartialEq for DataTableScopeInfo