#[non_exhaustive]pub struct RuleDeployment {
pub name: String,
pub enabled: bool,
pub alerting: bool,
pub archived: bool,
pub archive_time: Option<Timestamp>,
pub run_frequency: RunFrequency,
pub execution_state: ExecutionState,
pub producer_rules: Vec<String>,
pub consumer_rules: Vec<String>,
pub last_alert_status_change_time: Option<Timestamp>,
/* private fields */
}Expand description
The RuleDeployment resource represents the deployment state of a Rule.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name of the rule deployment.
Note that RuleDeployment is a child of the overall Rule, not any individual
revision, so the resource ID segment for the Rule resource must not
reference a specific revision.
Format:
projects/{project}/locations/{location}/instances/{instance}/rules/{rule}/deployment
enabled: boolWhether the rule is currently deployed continuously against incoming data.
alerting: boolWhether detections resulting from this deployment should be considered alerts.
archived: boolThe archive state of the rule deployment. Cannot be set to true unless enabled is set to false. If set to true, alerting will automatically be set to false. If currently set to true, enabled, alerting, and run_frequency cannot be updated.
archive_time: Option<Timestamp>Output only. The timestamp when the rule deployment archive state was last set to true. If the rule deployment’s current archive state is not set to true, the field will be empty.
run_frequency: RunFrequencyThe run frequency of the rule deployment.
execution_state: ExecutionStateOutput only. The execution state of the rule deployment.
producer_rules: Vec<String>Output only. The names of the associated/chained producer rules. Rules are
considered producers for this rule if this rule explicitly filters on their
ruleid. Format:
projects/{project}/locations/{location}/instances/{instance}/rules/{rule}
consumer_rules: Vec<String>Output only. The names of the associated/chained consumer rules. Rules are
considered consumers of this rule if their rule text explicitly filters on
this rule’s ruleid. Format:
projects/{project}/locations/{location}/instances/{instance}/rules/{rule}
last_alert_status_change_time: Option<Timestamp>Output only. The timestamp when the rule deployment alert state was lastly changed. This is filled regardless of the current alert state. E.g. if the current alert status is false, this timestamp will be the timestamp when the alert status was changed to false.
Implementations
Sourceimpl RuleDeployment
impl RuleDeployment
Sourcepub fn set_enabled<T: Into<bool>>(self, v: T) -> Self
pub fn set_enabled<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_alerting<T: Into<bool>>(self, v: T) -> Self
pub fn set_alerting<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_archived<T: Into<bool>>(self, v: T) -> Self
pub fn set_archived<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_archive_time<T>(self, v: T) -> Self
pub fn set_archive_time<T>(self, v: T) -> Self
Sets the value of archive_time.
Example
use wkt::Timestamp;
let x = RuleDeployment::new().set_archive_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_archive_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_archive_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of archive_time.
Example
use wkt::Timestamp;
let x = RuleDeployment::new().set_or_clear_archive_time(Some(Timestamp::default()/* use setters */));
let x = RuleDeployment::new().set_or_clear_archive_time(None::<Timestamp>);Sourcepub fn set_run_frequency<T: Into<RunFrequency>>(self, v: T) -> Self
pub fn set_run_frequency<T: Into<RunFrequency>>(self, v: T) -> Self
Sets the value of run_frequency.
Example
use google_cloud_chronicle_v1::model::RunFrequency;
let x0 = RuleDeployment::new().set_run_frequency(RunFrequency::Live);
let x1 = RuleDeployment::new().set_run_frequency(RunFrequency::Hourly);
let x2 = RuleDeployment::new().set_run_frequency(RunFrequency::Daily);Sourcepub fn set_execution_state<T: Into<ExecutionState>>(self, v: T) -> Self
pub fn set_execution_state<T: Into<ExecutionState>>(self, v: T) -> Self
Sets the value of execution_state.
Example
use google_cloud_chronicle_v1::model::rule_deployment::ExecutionState;
let x0 = RuleDeployment::new().set_execution_state(ExecutionState::Default);
let x1 = RuleDeployment::new().set_execution_state(ExecutionState::Limited);
let x2 = RuleDeployment::new().set_execution_state(ExecutionState::Paused);Sourcepub fn set_producer_rules<T, V>(self, v: T) -> Self
pub fn set_producer_rules<T, V>(self, v: T) -> Self
Sets the value of producer_rules.
Example
let x = RuleDeployment::new().set_producer_rules(["a", "b", "c"]);Sourcepub fn set_consumer_rules<T, V>(self, v: T) -> Self
pub fn set_consumer_rules<T, V>(self, v: T) -> Self
Sets the value of consumer_rules.
Example
let x = RuleDeployment::new().set_consumer_rules(["a", "b", "c"]);Sourcepub fn set_last_alert_status_change_time<T>(self, v: T) -> Self
pub fn set_last_alert_status_change_time<T>(self, v: T) -> Self
Sets the value of last_alert_status_change_time.
Example
use wkt::Timestamp;
let x = RuleDeployment::new().set_last_alert_status_change_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_last_alert_status_change_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_last_alert_status_change_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of last_alert_status_change_time.
Example
use wkt::Timestamp;
let x = RuleDeployment::new().set_or_clear_last_alert_status_change_time(Some(Timestamp::default()/* use setters */));
let x = RuleDeployment::new().set_or_clear_last_alert_status_change_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for RuleDeployment
impl Clone for RuleDeployment
Sourcefn clone(&self) -> RuleDeployment
fn clone(&self) -> RuleDeployment
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for RuleDeployment
impl Debug for RuleDeployment
Sourceimpl Default for RuleDeployment
impl Default for RuleDeployment
Sourcefn default() -> RuleDeployment
fn default() -> RuleDeployment
Sourceimpl Message for RuleDeployment
impl Message for RuleDeployment
Sourceimpl PartialEq for RuleDeployment
impl PartialEq for RuleDeployment
Sourcefn eq(&self, other: &RuleDeployment) -> bool
fn eq(&self, other: &RuleDeployment) -> bool
self and other values to be equal, and is used by ==.